import * as React from 'react';
import { TranslatorT } from '../../translation';
import { ISettingsEntity } from '../../settings';
import { IDateConverter, INumberConverter } from '../../converter';
import { AnyT } from '../../definitions.interface';
import { IUIFactory } from '../factory/factory.interface';
import { IAsyncLibManager, IDomAccessor, IEnvironment, IEventEmitter, IEventManager, IFieldConverter, IPlaceApi, IStorage, ITransport, IUniversalComponent, IUniversalComponentProps, IUniversalPlugin, IUniversalPluginCtor } from '../../definition';
export declare class UniversalComponent<TProps extends IUniversalComponentProps = IUniversalComponentProps, TState = {}, TSelfRef = AnyT> extends React.PureComponent<TProps, TState> implements IUniversalComponent<TProps, TState> {
    protected readonly plugins: IUniversalPlugin[];
    protected readonly selfRef: React.RefObject<TSelfRef>;
    private readonly defaultUiFactory;
    /**
     * @stable [02.12.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [22.09.2019]
     */
    componentDidMount(): void;
    /**
     * @stable [22.09.2019]
     */
    componentWillUnmount(): void;
    /**
     * @stable [23.10.2019]
     * @param {Readonly<TProps extends IUniversalComponentProps>} prevProps
     * @param {Readonly<TState>} prevState
     */
    getSnapshotBeforeUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>): void;
    /**
     * @stable [23.04.2018]
     * @param {Readonly<TProps>} prevProps
     * @param {Readonly<TState>} prevState
     * @param {never} prevContext
     */
    componentDidUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>, prevContext?: never): void;
    /**
     * @stable [01.12.2018]
     * @returns {Element}
     */
    getSelf(): Element;
    /**
     * @react-native-compatible
     * @stable [08.10.2019]
     * @returns {IEnvironment}
     */
    protected readonly environment: IEnvironment;
    /**
     * @react-native-compatible
     * @stable [08.10.2019]
     * @returns {IEventManager}
     */
    protected readonly eventManager: IEventManager;
    /**
     * @react-native-compatible
     * @stable [09.01.2020]
     * @returns {IFieldConverter}
     */
    protected readonly fieldConverter: IFieldConverter;
    /**
     * @react-native-compatible
     * @stable [17.01.2020]
     * @returns {IEventEmitter}
     */
    protected readonly eventEmitter: IEventEmitter;
    /**
     * @react-native-compatible
     * @stable [09.01.2020]
     * @returns {IPlaceApi}
     */
    protected readonly placeApi: IPlaceApi;
    /**
     * @react-native-compatible
     * @stable [09.01.2020]
     * @returns {IAsyncLibManager}
     */
    protected readonly asyncLibManager: IAsyncLibManager;
    /**
     * @reactNativeCompatible
     * @stable [22.09.2018]
     * @returns {TranslatorT}
     */
    protected readonly t: TranslatorT;
    /**
     * @reactNativeCompatible
     * @stable [29.07.2019]
     * @returns {ISettingsEntity}
     */
    protected readonly settings: ISettingsEntity;
    /**
     * @reactNativeCompatible
     * @stable [29.07.2019]
     * @returns {IStorage}
     */
    protected readonly databaseStorage: IStorage;
    /**
     * @stable [13.05.2018]
     * @returns {IDateConverter}
     */
    protected readonly dc: IDateConverter;
    /**
     * @reactNativeCompatible
     * @stable [22.09.2019]
     * @returns {INumberConverter}
     */
    protected readonly nc: INumberConverter;
    /**
     * @stable [18.05.2018]
     * @returns {IUIFactory}
     */
    protected readonly uiFactory: IUIFactory;
    /**
     * @stable [01.12.2018]
     * @returns {IDomAccessor}
     */
    protected readonly domAccessor: IDomAccessor;
    /**
     * @reactNativeCompatible
     * @stable [15.09.2019]
     * @returns {ITransport}
     */
    protected readonly transport: ITransport;
    /**
     * @stable [18.06.2019]
     * @param {IUniversalPluginCtor | IUniversalPlugin} pluginObject
     */
    protected registerPlugin(pluginObject: IUniversalPluginCtor | IUniversalPlugin): void;
    /**
     * @stable [18.06.2019]
     */
    private initPlugins;
    /**
     * @reactNativeCompatible
     * @stable [21.08.2019]
     * @returns {Map<IUniversalComponentCtor, UniversalPluginFactoryT>}
     */
    private readonly uiPlugins;
}
