"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var ReactDOM = require("react-dom");
var R = require("ramda");
var button_1 = require("../button");
var util_1 = require("../../util");
var perfect_scroll_plugin_1 = require("../plugin/perfect-scroll.plugin");
var definition_1 = require("../../definition");
var basic_component_1 = require("../base/basic.component");
var base_component_1 = require("../base/base.component");
var BaseDialog = /** @class */ (function (_super) {
    __extends(BaseDialog, _super);
    /**
     * @stable [06.01.2020]
     * @param {TProps} props
     */
    function BaseDialog(props) {
        var _this = _super.call(this, props) || this;
        _this.bodyRef = React.createRef();
        _this.onAcceptClick = _this.onAcceptClick.bind(_this);
        _this.onCloseClick = _this.onCloseClick.bind(_this);
        _this.onDialogScrimClick = _this.onDialogScrimClick.bind(_this);
        _this.onDocumentClickCapture = _this.onDocumentClickCapture.bind(_this);
        _this.state = { opened: false };
        if (util_1.isCheckScrimNeeded(props)) {
            _this.doesAnotherScrimLayerExist = _this.domAccessor.hasElements(BaseDialog.DIALOG_SCRIM_SELECTOR, _this.portalElement);
        }
        return _this;
    }
    /**
     * @stable [25.01.2020]
     * @returns {React.ReactNode}
     */
    BaseDialog.prototype.render = function () {
        var _this = this;
        return util_1.orNull(this.state.opened, function () {
            var isAnchored = _this.isAnchored;
            return ReactDOM.createPortal(React.createElement("div", __assign({ ref: _this.selfRef, className: util_1.joinClassName(_this.dialogClassName, !isAnchored && 'rac-absolute rac-full-size', isAnchored || _this.doesAnotherScrimLayerExist
                    ? 'rac-dialog__transparent-scrim'
                    : BaseDialog.DIALOG_SCRIM_CLASS_NAME) }, util_1.handlerPropsFactory(_this.onDialogScrimClick, !isAnchored, false)), _this.dialogBodyElement), _this.portalElement);
        });
    };
    /**
     * @stable [25.01.2020]
     */
    BaseDialog.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this.unsubscribeEvents();
    };
    /**
     * @stable [24.01.2020]
     * @param {IActivateDialogConfigEntity} payload
     */
    BaseDialog.prototype.activate = function (payload) {
        var _this = this;
        var props = this.props;
        this.setState({ opened: true }, function () {
            _this.onAfterRender();
            var _a = payload || {}, onActivate = _a.onActivate, onDeactivate = _a.onDeactivate;
            if (util_1.isFn(onDeactivate)) {
                _this.onDeactivateCallback = onDeactivate;
            }
            if (util_1.isFn(onActivate)) {
                onActivate.call(_this);
            }
            if (util_1.isFn(props.onActivate)) {
                props.onActivate();
            }
        });
    };
    /**
     * @stable [06.01.2020]
     */
    BaseDialog.prototype.accept = function () {
        this.onAcceptClick();
    };
    /**
     * @stable [06.01.2020]
     */
    BaseDialog.prototype.onAcceptClick = function () {
        var props = this.props;
        this.doClose(function () {
            if (util_1.isFn(props.onAccept)) {
                props.onAccept();
            }
        });
    };
    /**
     * @stable [05.01.2020]
     */
    BaseDialog.prototype.onCloseClick = function () {
        var props = this.props;
        this.doClose(function () {
            if (util_1.isFn(props.onClose)) {
                props.onClose();
            }
        });
    };
    /**
     * @stable [05.01.2020]
     */
    BaseDialog.prototype.onDialogScrimClick = function () {
        this.doClose();
    };
    /**
     * @stable [25.01.2020]
     */
    BaseDialog.prototype.onDocumentClickCapture = function (event) {
        var target = event.target;
        if (this.domAccessor.hasParent(BaseDialog.DIALOG_SELECTOR, target)) {
            return;
        }
        this.doClose();
    };
    /**
     * @stable [25.01.2020]
     */
    BaseDialog.prototype.onAfterRender = function () {
        if (!this.isAnchored) {
            return;
        }
        this.unsubscribeEvents();
        var props = this.props;
        this.domAccessor.setPosition(__assign({}, props.positionConfiguration, { element: this.bodyRef.current, of: util_1.calc(props.anchorElement) }));
        this.closeEventUnsubscriber = this.domAccessor.captureEvent({
            eventName: definition_1.EventsEnum.CLICK,
            capture: true,
            callback: this.onDocumentClickCapture,
        });
    };
    /**
     * @stable [05.01.2020]
     * @param {() => void} callback
     */
    BaseDialog.prototype.doClose = function (callback) {
        var _this = this;
        var props = this.props;
        this.setState({ opened: false }, function () {
            _this.unsubscribeEvents();
            if (util_1.isFn(_this.onDeactivateCallback)) {
                _this.onDeactivateCallback.call(_this);
                _this.onDeactivateCallback = null;
            }
            if (util_1.isFn(props.onDeactivate)) {
                props.onDeactivate();
            }
            if (util_1.isFn(callback)) {
                callback.call(_this);
            }
        });
    };
    Object.defineProperty(BaseDialog.prototype, "footerElement", {
        /**
         * @stable [24.03.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            return (util_1.orNull(this.closable || this.acceptable, function () { return (React.createElement("div", { className: 'rac-dialog__actions' },
                util_1.orNull(_this.closable, function () { return (React.createElement(button_1.Button, { icon: 'close', full: true, disabled: _this.isCloseButtonDisabled, onClick: _this.onCloseClick }, _this.t(props.closeText || _this.settings.messages.DIALOG_CANCEL))); }),
                util_1.orNull(_this.acceptable, function () { return (React.createElement(button_1.Button, { icon: 'ok-filled', full: true, raised: true, disabled: _this.isAcceptButtonDisabled, onClick: _this.onAcceptClick }, _this.t(props.acceptText || _this.settings.messages.DIALOG_ACCEPT))); }))); }));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "dialogBodyElement", {
        /**
         * @stable [24.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement("div", { ref: this.bodyRef, style: { width: util_1.calc(this.props.width) }, className: 'rac-dialog__body', onClick: this.domAccessor.cancelEvent },
                this.bodyElement,
                this.footerElement));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "bodyElement", {
        /**
         * @stable [06.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _a = this.props, children = _a.children, title = _a.title;
            return (React.createElement(React.Fragment, null,
                title && (React.createElement("div", { className: 'rac-dialog__body-title' }, this.t(title))),
                children && (React.createElement(basic_component_1.BasicComponent, { className: 'rac-dialog__body-content', plugins: util_1.isScrollable(this.props) ? [perfect_scroll_plugin_1.PerfectScrollPlugin] : [] }, children))));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [25.01.2020]
     */
    BaseDialog.prototype.unsubscribeEvents = function () {
        if (util_1.isFn(this.closeEventUnsubscriber)) {
            this.closeEventUnsubscriber();
            this.closeEventUnsubscriber = null;
        }
    };
    Object.defineProperty(BaseDialog.prototype, "acceptable", {
        /**
         * @stable [06.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.props.acceptable !== false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "closable", {
        /**
         * @stable [06.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.props.closable !== false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "isCloseButtonDisabled", {
        /**
         * @stable [06.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.props.closeDisabled === true;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "isAcceptButtonDisabled", {
        /**
         * @stable [06.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.props.acceptDisabled === true;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "portalElement", {
        /**
         * @stable [15.01.2020]
         * @returns {Element}
         */
        get: function () {
            return this.domAccessor.documentBody;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "isAnchored", {
        /**
         * @stable [24.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.props.anchorElement);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseDialog.prototype, "dialogClassName", {
        /**
         * @stable [05.01.2020]
         * @returns {string}
         */
        get: function () {
            var props = this.props;
            return util_1.joinClassName(BaseDialog.DIALOG_CLASS_NAME, util_1.isDefault(props) && 'rac-default-dialog', this.isAnchored ? 'rac-anchored-dialog' : 'rac-not-anchored-dialog', props.className);
        },
        enumerable: true,
        configurable: true
    });
    BaseDialog.DIALOG_CLASS_NAME = 'rac-dialog';
    BaseDialog.DIALOG_SCRIM_CLASS_NAME = 'rac-dialog__scrim';
    BaseDialog.DIALOG_SCRIM_SELECTOR = "." + BaseDialog.DIALOG_SCRIM_CLASS_NAME;
    BaseDialog.DIALOG_SELECTOR = "." + BaseDialog.DIALOG_CLASS_NAME;
    return BaseDialog;
}(base_component_1.BaseComponent));
exports.BaseDialog = BaseDialog;
//# sourceMappingURL=base-dialog.component.js.map