/// <reference types="react" />
import { AnyT, EntityIdT } from '../../../definitions.interface';
import { DateTimeLikeTypeT, IBaseEvent } from '../../../definition';
import { IDateFieldProps, IDateFieldState } from './date-field.interface';
import { BaseTextField } from '../text-field';
export declare class DateField<TProps extends IDateFieldProps = IDateFieldProps, TState extends IDateFieldState = IDateFieldState> extends BaseTextField<TProps, TState> {
    static readonly defaultProps: IDateFieldProps;
    private readonly defaultRangeFieldProps;
    private readonly dialogRef;
    private readonly yearRef;
    /**
     * @stable [07.01.2020]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [20.01.2020]
     * @param {DateTimeLikeTypeT[] | DateTimeLikeTypeT | AnyT} currentRawValue
     */
    onChangeManually(currentRawValue: DateTimeLikeTypeT[] | DateTimeLikeTypeT | AnyT): void;
    /**
     * @stable [09.01.2020]
     * @returns {JSX.Element}
     */
    protected getAttachmentElement(): JSX.Element;
    /**
     * @stable [20.01.2020]
     * @returns {EntityIdT[] | string}
     */
    protected readonly originalEmptyValue: EntityIdT[] | string;
    /**
     * @stable [09.01.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [07.01.2019]
     * @param {AnyT} value
     * @returns {string}
     */
    protected decorateValueBeforeDisplaying(value: DateTimeLikeTypeT): string;
    /**
     * @stable [02.05.2019]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [07.01.2020]
     * @returns {string}
     */
    protected getFieldPattern(): string;
    /**
     * @stable [07.01.2020]
     * @returns {Array<string | RegExp>}
     */
    protected getFieldMask(): Array<string | RegExp>;
    /**
     * @stable [07.01.2020]
     * @returns {string}
     */
    protected readonly fieldFormat: string;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    private readonly calendarAttachmentElement;
    /**
     * @stable [20.01.2020]
     * @returns {JSX.Element}
     */
    private readonly calendarElement;
    /**
     * @stable [21.01.2020]
     * @returns {ICalendarProps}
     */
    private readonly defaultCalendarProps;
    /**
     * @stable [20.01.2020]
     * @returns {React.ReactNode}
     */
    private readonly rangeExplorerDateElement;
    /**
     * @stable [20.01.2020]
     * @returns {JSX.Element}
     */
    private readonly rangeFieldsElement;
    /**
     * @stable [21.01.2020]
     * @returns {JSX.Element}
     */
    private readonly quickButtonsElement;
    /**
     * @stable [21.01.2020]
     */
    private onSetWeek;
    /**
     * @stable [21.01.2020]
     */
    private onSetMonth;
    /**
     * @stable [21.01.2020]
     */
    private onSetQuarter;
    /**
     * @stable [21.01.2020]
     */
    private onSetYear;
    /**
     * @stable [21.01.2020]
     * @param {Date} current
     * @param {Date} next
     */
    private setQuickValue;
    /**
     * @stable [08.01.2020]
     */
    private setPreviousMonth;
    /**
     * @stable [08.01.2020]
     */
    private setNextMonth;
    /**
     * @stable [08.01.2020]
     * @param {number} duration
     */
    private changeMonth;
    /**
     * @stable [20.01.2020]
     * @param {string} value
     */
    private onRangeToChange;
    /**
     * @stable [20.01.2020]
     * @param {string} value
     */
    private onRangeFromChange;
    /**
     * @stable [08.01.2020]
     * @param {number} year
     */
    private onChangeYear;
    /**
     * @stable [17.01.2020]
     */
    private onAccept;
    /**
     * @stable [17.01.2020]
     * @param {ICalendarDayEntity} calendarDayEntity
     */
    private onDaySelect;
    /**
     * @stable [20.01.2020]
     * @param {ICalendarDayEntity} calendarDayEntity
     */
    private onRangeDaySelect;
    /**
     * @stable [09.01.2020]
     */
    private onDialogDeactivate;
    /**
     * @stable [09.01.2020]
     * @param {() => void} callback
     */
    private onDialogClose;
    /**
     * @stable [24.02.2019]
     */
    private openDialog;
    /**
     * @stable [08.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isDaySelected;
    /**
     * @stable [21.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isFirstSelectedDay;
    /**
     * @stable [21.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isLastSelectedDay;
    /**
     * @stable [20.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isRangeSelected;
    /**
     * @stable [20.01.2020]
     * @returns {Date}
     */
    private readonly valueAsDate;
    /**
     * @stable [20.01.2020]
     * @param {DateTimeLikeTypeT} date
     * @returns {Date}
     */
    private getValueAsDate;
    /**
     * @stable [20.01.2020]
     * @returns {Date[]}
     */
    private readonly valueAsDatesArray;
    /**
     * @stable [20.01.2020]
     * @param {DateTimeLikeTypeT} value
     * @returns {string}
     */
    private serializeValue;
    /**
     * @stable [08.01.2020]
     * @returns {string}
     */
    private readonly currentDateToDisplay;
    /**
     * @stable [20.01.2020]
     * @returns {string}
     */
    private readonly nextDateToDisplay;
    /**
     * @stable [20.01.2020]
     * @returns {ICalendarEntity}
     */
    private readonly currentCalendarEntity;
    /**
     * @stable [20.01.2020]
     * @returns {ICalendarEntity}
     */
    private readonly nextCalendarEntity;
    /**
     * @stable [21.01.2020]
     * @param {Date} date
     * @returns {ICalendarEntity}
     */
    private getCalendarEntity;
    /**
     * @stable [20.01.2020]
     * @returns {Date}
     */
    private readonly currentCalendarDate;
    /**
     * @stable [20.01.2020]
     * @returns {Date}
     */
    private readonly nextCalendarDate;
    /**
     * @stable [17.01.2020]
     * @returns {Date}
     */
    private readonly dateValueToAccept;
    /**
     * @stable [20.01.2020]
     * @returns {Date[]}
     */
    private readonly rangeValueToAccept;
    /**
     * @stable [08.01.2020]
     * @returns {string}
     */
    private readonly selectedYearPlaceholder;
    /**
     * stable [07.01.2020]
     * @returns {IDateTimeSettingsEntity}
     */
    private readonly dateTimeSettings;
    /**
     * @stable [24.02.2019]
     * @returns {Dialog}
     */
    private readonly dialog;
    /**
     * @stable [20.01.2020]
     * @returns {boolean}
     */
    private readonly isRangeEnabled;
    /**
     * @stable [22.01.2020]
     * @returns {boolean}
     */
    private readonly isInline;
    /**
     * @stable [20.01.2020]
     * @returns {IFromToDayOfYearEntity}
     */
    private readonly currentFromToDayOfYearEntity;
}
