"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var definitions_interface_1 = require("../../../definitions.interface");
var definition_1 = require("../../../definition");
var text_field_1 = require("../text-field");
var button_1 = require("../../button");
var calendar_1 = require("../../calendar");
var dialog_1 = require("../../dialog");
var numberfield_1 = require("../numberfield");
var DateField = /** @class */ (function (_super) {
    __extends(DateField, _super);
    /**
     * @stable [07.01.2020]
     * @param {TProps} props
     */
    function DateField(props) {
        var _this = _super.call(this, props) || this;
        _this.defaultRangeFieldProps = {
            calendarActionRendered: false,
            errorMessageRendered: false,
            full: false,
            placeholder: _this.fieldFormat,
            preventFocus: false,
        };
        _this.dialogRef = React.createRef();
        _this.yearRef = React.createRef();
        _this.isDaySelected = _this.isDaySelected.bind(_this);
        _this.isFirstSelectedDay = _this.isFirstSelectedDay.bind(_this);
        _this.isLastSelectedDay = _this.isLastSelectedDay.bind(_this);
        _this.onAccept = _this.onAccept.bind(_this);
        _this.onChangeYear = _this.onChangeYear.bind(_this);
        _this.onDaySelect = _this.onDaySelect.bind(_this);
        _this.onDialogDeactivate = _this.onDialogDeactivate.bind(_this);
        _this.onRangeFromChange = _this.onRangeFromChange.bind(_this);
        _this.onRangeToChange = _this.onRangeToChange.bind(_this);
        _this.onSetMonth = _this.onSetMonth.bind(_this);
        _this.onSetQuarter = _this.onSetQuarter.bind(_this);
        _this.onSetWeek = _this.onSetWeek.bind(_this);
        _this.onSetYear = _this.onSetYear.bind(_this);
        _this.openDialog = _this.openDialog.bind(_this);
        _this.setNextMonth = _this.setNextMonth.bind(_this);
        _this.setPreviousMonth = _this.setPreviousMonth.bind(_this);
        _this.defaultActions = (!_this.isInline && util_1.isCalendarActionRendered(_this.props)
            ? [{ type: definition_1.FieldActionTypesEnum.CALENDAR, onClick: _this.openDialog }]
            : []).concat(_this.defaultActions);
        return _this;
    }
    /**
     * @stable [20.01.2020]
     * @param {DateTimeLikeTypeT[] | DateTimeLikeTypeT | AnyT} currentRawValue
     */
    DateField.prototype.onChangeManually = function (currentRawValue) {
        _super.prototype.onChangeManually.call(this, this.isRangeEnabled
            ? util_1.notEmptyValuesArrayFilter(this.serializeValue(currentRawValue[0]), this.serializeValue(currentRawValue[1]))
            : this.serializeValue(currentRawValue));
    };
    /**
     * @stable [09.01.2020]
     * @returns {JSX.Element}
     */
    DateField.prototype.getAttachmentElement = function () {
        var _this = this;
        var props = this.props;
        var dialogOpened = this.state.dialogOpened;
        var _a = props.dialogConfiguration, dialogConfiguration = _a === void 0 ? {} : _a;
        var className = util_1.joinClassName(!this.isInline && dialogConfiguration.className, 'rac-calendar-base-dialog', this.isInline ? 'rac-calendar-inline-dialog' : 'rac-calendar-dialog', this.isRangeEnabled ? 'rac-date-field__calendars-dialog' : 'rac-date-field__calendar-dialog');
        if (this.isInline) {
            return (React.createElement("div", { className: className }, this.calendarAttachmentElement));
        }
        return util_1.orNull(dialogOpened, // To improve a performance
        function () { return (React.createElement(dialog_1.Dialog, __assign({ checkScrim: true }, props.dialogConfiguration, { ref: _this.dialogRef, acceptable: false, closable: false, className: className, onDeactivate: _this.onDialogDeactivate }), _this.calendarAttachmentElement)); });
    };
    Object.defineProperty(DateField.prototype, "originalEmptyValue", {
        /**
         * @stable [20.01.2020]
         * @returns {EntityIdT[] | string}
         */
        get: function () {
            return this.isRangeEnabled ? [] : definition_1.FIELD_DISPLAY_EMPTY_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [09.01.2020]
     * @param {IBaseEvent} event
     */
    DateField.prototype.onClick = function (event) {
        _super.prototype.onClick.call(this, event);
        if (!this.isInline && this.isFocusPrevented) {
            this.openDialog();
        }
    };
    /**
     * @stable [07.01.2019]
     * @param {AnyT} value
     * @returns {string}
     */
    DateField.prototype.decorateValueBeforeDisplaying = function (value) {
        return this.isRangeEnabled
            ? this.serializeValue(value[0]) + " - " + this.serializeValue(value[1])
            : this.serializeValue(value);
    };
    /**
     * @stable [02.05.2019]
     * @returns {string}
     */
    DateField.prototype.getFieldClassName = function () {
        return util_1.joinClassName(_super.prototype.getFieldClassName.call(this), 'rac-date-field');
    };
    /**
     * @stable [07.01.2020]
     * @returns {string}
     */
    DateField.prototype.getFieldPattern = function () {
        var _this = this;
        return util_1.orNull(!this.isDisplayValueDefined && !this.isRangeEnabled, function () { return _super.prototype.getFieldPattern.call(_this) || _this.dateTimeSettings.uiDatePattern; });
    };
    /**
     * @stable [07.01.2020]
     * @returns {Array<string | RegExp>}
     */
    DateField.prototype.getFieldMask = function () {
        var _this = this;
        return util_1.orNull(!this.isDisplayValueDefined && !this.isRangeEnabled, function () { return _super.prototype.getFieldMask.call(_this) || _this.dateTimeSettings.uiDateMask; });
    };
    Object.defineProperty(DateField.prototype, "fieldFormat", {
        /**
         * @stable [07.01.2020]
         * @returns {string}
         */
        get: function () {
            return util_1.nvl(this.props.format, this.dateTimeSettings.uiDateFormat);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "calendarAttachmentElement", {
        /**
         * @stable [22.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var year = this.state.year;
            return (React.createElement(React.Fragment, null,
                this.isRangeEnabled && this.quickButtonsElement,
                React.createElement("div", { className: 'rac-calendar-dialog__range-explorer' },
                    React.createElement(button_1.Button, { icon: 'back', mini: true, onClick: this.setPreviousMonth }),
                    React.createElement("div", { className: 'rac-calendar-dialog__range-explorer-date' }, this.rangeExplorerDateElement),
                    React.createElement(button_1.Button, { icon: 'forward', mini: true, onClick: this.setNextMonth })),
                this.calendarElement,
                React.createElement("div", { className: 'rac-calendar-dialog__footer' },
                    this.isRangeEnabled && this.rangeFieldsElement,
                    !this.isRangeEnabled && (React.createElement(numberfield_1.NumberField, { ref: this.yearRef, value: year, full: false, autoFocus: true, keepChanges: true, errorMessageRendered: false, pattern: this.dateTimeSettings.uiYearPattern, mask: this.dateTimeSettings.uiYearMask, placeholder: this.selectedYearPlaceholder, onChange: this.onChangeYear })),
                    !this.isInline && (React.createElement(button_1.Button, { text: this.settings.messages.OK, onClick: this.onAccept })))));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "calendarElement", {
        /**
         * @stable [20.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var defaultCalendarProps = this.defaultCalendarProps;
            var _a = defaultCalendarProps.gridConfiguration, gridConfiguration = _a === void 0 ? {} : _a;
            if (this.isRangeEnabled) {
                return (React.createElement("div", { className: 'rac-calendar-dialog__calendars-wrapper' },
                    React.createElement(calendar_1.Calendar, __assign({}, defaultCalendarProps, { calendarEntity: this.currentCalendarEntity })),
                    React.createElement(calendar_1.Calendar, __assign({}, defaultCalendarProps, { gridConfiguration: __assign({}, gridConfiguration, { wrapperClassName: util_1.joinClassName('rac-calendar-dialog__second-calendar', gridConfiguration.className) }), calendarEntity: this.nextCalendarEntity }))));
            }
            return (React.createElement(calendar_1.Calendar, __assign({}, defaultCalendarProps, { calendarEntity: this.currentCalendarEntity })));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "defaultCalendarProps", {
        /**
         * @stable [21.01.2020]
         * @returns {ICalendarProps}
         */
        get: function () {
            return __assign({ gridConfiguration: { headerRendered: true }, showOnlyCurrentDays: true }, this.props.calendarConfiguration, { isSelected: this.isDaySelected, isFirstSelected: this.isFirstSelectedDay, isLastSelected: this.isLastSelectedDay, onSelect: this.onDaySelect });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "rangeExplorerDateElement", {
        /**
         * @stable [20.01.2020]
         * @returns {React.ReactNode}
         */
        get: function () {
            if (this.isRangeEnabled) {
                return (React.createElement(React.Fragment, null,
                    React.createElement("div", { className: 'rac-calendar-dialog__range-explorer-date-content' }, this.currentDateToDisplay),
                    React.createElement("div", { className: 'rac-calendar-dialog__range-explorer-date-content rac-calendar-dialog__range-explorer-date-content-next' }, this.nextDateToDisplay)));
            }
            return this.currentDateToDisplay;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "rangeFieldsElement", {
        /**
         * @stable [20.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(React.Fragment, null,
                React.createElement(DateField, __assign({}, this.defaultRangeFieldProps, { value: this.state.from, onChange: this.onRangeFromChange })),
                React.createElement("span", { className: 'rac-calendar-dialog__range-input-separator' }, "\u00A0\u2014\u00A0"),
                React.createElement(DateField, __assign({}, this.defaultRangeFieldProps, { value: this.state.to, onChange: this.onRangeToChange }))));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "quickButtonsElement", {
        /**
         * @stable [21.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement("div", { className: 'rac-calendar-dialog__quick-buttons' },
                React.createElement(button_1.Button, { full: true, text: this.settings.messages.WEEK, onClick: this.onSetWeek }),
                React.createElement(button_1.Button, { full: true, text: this.settings.messages.MONTH, onClick: this.onSetMonth }),
                React.createElement(button_1.Button, { full: true, text: this.settings.messages.QUARTER, onClick: this.onSetQuarter }),
                React.createElement(button_1.Button, { full: true, text: this.settings.messages.YEAR, onClick: this.onSetYear })));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [21.01.2020]
     */
    DateField.prototype.onSetWeek = function () {
        this.setQuickValue(this.dc.asFirstDayOfWeekAsDate(), this.dc.asDayOfYear());
    };
    /**
     * @stable [21.01.2020]
     */
    DateField.prototype.onSetMonth = function () {
        this.setQuickValue(this.dc.asFirstDayOfMonthAsDate(), this.dc.asDayOfYear());
    };
    /**
     * @stable [21.01.2020]
     */
    DateField.prototype.onSetQuarter = function () {
        this.setQuickValue(this.dc.asFirstDayOfQuarterAsDate(), this.dc.asDayOfYear());
    };
    /**
     * @stable [21.01.2020]
     */
    DateField.prototype.onSetYear = function () {
        this.setQuickValue(this.dc.asFirstDayOfYearAsDate(), this.dc.asDayOfYear());
    };
    /**
     * @stable [21.01.2020]
     * @param {Date} current
     * @param {Date} next
     */
    DateField.prototype.setQuickValue = function (current, next) {
        this.setState({
            cursor: next,
            from: this.serializeValue(current),
            to: this.serializeValue(next),
            current: current,
            next: next,
        });
    };
    /**
     * @stable [08.01.2020]
     */
    DateField.prototype.setPreviousMonth = function () {
        this.changeMonth(-1);
    };
    /**
     * @stable [08.01.2020]
     */
    DateField.prototype.setNextMonth = function () {
        this.changeMonth(1);
    };
    /**
     * @stable [08.01.2020]
     * @param {number} duration
     */
    DateField.prototype.changeMonth = function (duration) {
        this.setState({ cursor: this.dc.addMonthsAsDate({ date: this.currentCalendarDate, duration: duration }) });
    };
    /**
     * @stable [20.01.2020]
     * @param {string} value
     */
    DateField.prototype.onRangeToChange = function (value) {
        var date = this.getValueAsDate(value);
        this.setState(R.isNil(date) ? { to: value } : { to: value, next: date });
    };
    /**
     * @stable [20.01.2020]
     * @param {string} value
     */
    DateField.prototype.onRangeFromChange = function (value) {
        var date = this.getValueAsDate(value);
        this.setState(R.isNil(date) ? { from: value } : { from: value, current: date });
    };
    /**
     * @stable [08.01.2020]
     * @param {number} year
     */
    DateField.prototype.onChangeYear = function (year) {
        var props = this.props;
        var current = this.dc.fromDayOfYearEntityAsDate({ year: year }, { date: this.dateValueToAccept || this.dc.asDayOfYear() });
        if (this.dc.isDateBelongToDatesRange({ date: current, minDate: props.minDate, maxDate: props.maxDate })) {
            this.setState({ cursor: definitions_interface_1.UNDEF, year: year, current: current });
        }
        else {
            this.setState({ cursor: definitions_interface_1.UNDEF, year: year });
        }
    };
    /**
     * @stable [17.01.2020]
     */
    DateField.prototype.onAccept = function () {
        var _this = this;
        var valueToAccept = this.isRangeEnabled ? this.rangeValueToAccept : this.dateValueToAccept;
        this.onDialogClose(function () {
            util_1.ifNotNilThanValue(valueToAccept, function () { return _this.onChangeManually(valueToAccept); });
            if (!_this.isFocusPrevented) {
                _this.setFocus();
            }
        });
    };
    /**
     * @stable [17.01.2020]
     * @param {ICalendarDayEntity} calendarDayEntity
     */
    DateField.prototype.onDaySelect = function (calendarDayEntity) {
        var _this = this;
        if (this.isRangeEnabled) {
            this.onRangeDaySelect(calendarDayEntity);
        }
        else {
            this.setState({
                cursor: definitions_interface_1.UNDEF,
                year: calendarDayEntity.year,
                current: calendarDayEntity.date,
            }, function () { return _this.yearRef.current.setFocus(); });
        }
    };
    /**
     * @stable [20.01.2020]
     * @param {ICalendarDayEntity} calendarDayEntity
     */
    DateField.prototype.onRangeDaySelect = function (calendarDayEntity) {
        var _this = this;
        var result = this.dc.selectDaysOfYearRange(this.currentFromToDayOfYearEntity, calendarDayEntity);
        this.setState(__assign({ current: null, next: null }, util_1.ifNotEmptyThanValue(result.from, function (from) { return ({ current: _this.dc.fromDayOfYearEntityAsDate(from) }); }), util_1.ifNotEmptyThanValue(result.to, function (to) { return ({ next: _this.dc.fromDayOfYearEntityAsDate(to) }); })));
    };
    /**
     * @stable [09.01.2020]
     */
    DateField.prototype.onDialogDeactivate = function () {
        this.onDialogClose();
    };
    /**
     * @stable [09.01.2020]
     * @param {() => void} callback
     */
    DateField.prototype.onDialogClose = function (callback) {
        this.setState({
            dialogOpened: false,
            current: definitions_interface_1.UNDEF,
            cursor: definitions_interface_1.UNDEF,
            from: definitions_interface_1.UNDEF,
            next: definitions_interface_1.UNDEF,
            to: definitions_interface_1.UNDEF,
            year: definitions_interface_1.UNDEF,
        }, callback);
    };
    /**
     * @stable [24.02.2019]
     */
    DateField.prototype.openDialog = function () {
        var _this = this;
        this.setState({ dialogOpened: true }, function () { return _this.dialog.activate(); });
    };
    /**
     * @stable [08.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    DateField.prototype.isDaySelected = function (entity) {
        return this.isRangeEnabled
            ? this.isRangeSelected(entity)
            : this.dc.compare(entity.date, this.dateValueToAccept) === 0;
    };
    /**
     * @stable [21.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    DateField.prototype.isFirstSelectedDay = function (entity) {
        return this.isRangeEnabled && this.dc.isDayOfYearBelongToDaysOfYearRange(__assign({}, this.currentFromToDayOfYearEntity, { to: {} }), entity);
    };
    /**
     * @stable [21.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    DateField.prototype.isLastSelectedDay = function (entity) {
        return this.isRangeEnabled && this.dc.isDayOfYearBelongToDaysOfYearRange(__assign({}, this.currentFromToDayOfYearEntity, { from: {} }), entity);
    };
    /**
     * @stable [20.01.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    DateField.prototype.isRangeSelected = function (entity) {
        return this.dc.isDayOfYearBelongToDaysOfYearRange(this.currentFromToDayOfYearEntity, entity);
    };
    Object.defineProperty(DateField.prototype, "valueAsDate", {
        /**
         * @stable [20.01.2020]
         * @returns {Date}
         */
        get: function () {
            return this.getValueAsDate(this.value);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [20.01.2020]
     * @param {DateTimeLikeTypeT} date
     * @returns {Date}
     */
    DateField.prototype.getValueAsDate = function (date) {
        return this.dc.asDate({ date: date, inputFormat: this.fieldFormat });
    };
    Object.defineProperty(DateField.prototype, "valueAsDatesArray", {
        /**
         * @stable [20.01.2020]
         * @returns {Date[]}
         */
        get: function () {
            var _this = this;
            return util_1.ifNotEmptyThanValue(this.value, function (value) { return ([_this.getValueAsDate(value[0]), _this.getValueAsDate(value[1])]); }, []);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [20.01.2020]
     * @param {DateTimeLikeTypeT} value
     * @returns {string}
     */
    DateField.prototype.serializeValue = function (value) {
        return this.dc.dateAsString({ date: value, inputFormat: this.fieldFormat, outputFormat: this.fieldFormat });
    };
    Object.defineProperty(DateField.prototype, "currentDateToDisplay", {
        /**
         * @stable [08.01.2020]
         * @returns {string}
         */
        get: function () {
            return this.dc.dateAsString({ date: this.currentCalendarDate, outputFormat: this.props.headerFormat });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "nextDateToDisplay", {
        /**
         * @stable [20.01.2020]
         * @returns {string}
         */
        get: function () {
            return this.dc.dateAsString({ date: this.nextCalendarDate, outputFormat: this.props.headerFormat });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "currentCalendarEntity", {
        /**
         * @stable [20.01.2020]
         * @returns {ICalendarEntity}
         */
        get: function () {
            return this.getCalendarEntity(this.currentCalendarDate);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "nextCalendarEntity", {
        /**
         * @stable [20.01.2020]
         * @returns {ICalendarEntity}
         */
        get: function () {
            return this.getCalendarEntity(this.nextCalendarDate);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [21.01.2020]
     * @param {Date} date
     * @returns {ICalendarEntity}
     */
    DateField.prototype.getCalendarEntity = function (date) {
        return this.dc.asCalendar(__assign({}, this.props.calendarEntityConfiguration, { date: date }));
    };
    Object.defineProperty(DateField.prototype, "currentCalendarDate", {
        /**
         * @stable [20.01.2020]
         * @returns {Date}
         */
        get: function () {
            return this.state.cursor
                || (this.isRangeEnabled ? this.rangeValueToAccept[0] : this.dateValueToAccept)
                || this.dc.asDayOfYear();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "nextCalendarDate", {
        /**
         * @stable [20.01.2020]
         * @returns {Date}
         */
        get: function () {
            return this.dc.addMonths({ date: this.currentCalendarDate, duration: 1 });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dateValueToAccept", {
        /**
         * @stable [17.01.2020]
         * @returns {Date}
         */
        get: function () {
            return this.state.current || this.valueAsDate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "rangeValueToAccept", {
        /**
         * @stable [20.01.2020]
         * @returns {Date[]}
         */
        get: function () {
            return [
                this.state.current || util_1.ifNotNilThanValue(this.valueAsDatesArray, function (data) { return data[0]; }),
                this.state.next || util_1.ifNotNilThanValue(this.valueAsDatesArray, function (data) { return data[1]; })
            ];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "selectedYearPlaceholder", {
        /**
         * @stable [08.01.2020]
         * @returns {string}
         */
        get: function () {
            var _this = this;
            return util_1.ifNotNilThanValue(this.valueAsDate, function (selectedDate) { return String(_this.dc.asDayOfYearEntity({ date: selectedDate }).year); }, this.settings.dateTime.uiYearFormat);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dateTimeSettings", {
        /**
         * stable [07.01.2020]
         * @returns {IDateTimeSettingsEntity}
         */
        get: function () {
            return this.settings.dateTime || {};
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "dialog", {
        /**
         * @stable [24.02.2019]
         * @returns {Dialog}
         */
        get: function () {
            return this.dialogRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "isRangeEnabled", {
        /**
         * @stable [20.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isRangeEnabled(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "isInline", {
        /**
         * @stable [22.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isInline(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DateField.prototype, "currentFromToDayOfYearEntity", {
        /**
         * @stable [20.01.2020]
         * @returns {IFromToDayOfYearEntity}
         */
        get: function () {
            var _this = this;
            var _a = this.state, current = _a.current, next = _a.next;
            var valueArray = this.valueAsDatesArray;
            return util_1.notNilValuesFilter(__assign({}, util_1.ifNotNilThanValue(valueArray[0], function (dateFrom) { return ({ from: _this.dc.asDayOfYearEntity({ date: dateFrom }) }); }), util_1.ifNotNilThanValue(valueArray[1], function (dateTo) { return ({ to: _this.dc.asDayOfYearEntity({ date: dateTo }) }); }), (util_1.isDef(current)
                ? ({ from: util_1.ifNotNilThanValue(current, function () { return _this.dc.asDayOfYearEntity({ date: current }); }) })
                : ({})), (util_1.isDef(next)
                ? ({ to: util_1.ifNotNilThanValue(next, function () { return _this.dc.asDayOfYearEntity({ date: next }); }) })
                : ({}))));
        },
        enumerable: true,
        configurable: true
    });
    DateField.defaultProps = {
        headerFormat: 'MMMM YYYY',
        preventFocus: true,
    };
    return DateField;
}(text_field_1.BaseTextField));
exports.DateField = DateField;
//# sourceMappingURL=date-field.component.js.map