import * as React from 'react';
import { AnyT, IChangeEvent, IKeyboardEvent } from '../../../definitions.interface';
import { IField, IFieldState } from './field.interface';
import { UniversalField } from './universal-field.component';
import { IBaseEvent, IFieldActionEntity, IFieldComplexInputAttributes, IJQueryElement, IMaskedInputCtor, InputElementT } from '../../../definition';
import { IFieldProps } from '../../../configurations-definitions.interface';
export declare class Field<TProps extends IFieldProps, TState extends IFieldState = IFieldState> extends UniversalField<TProps, TState> implements IField<TProps, TState> {
    protected defaultActions: IFieldActionEntity[];
    protected readonly inputRef: React.RefObject<HTMLInputElement | HTMLTextAreaElement | IMaskedInputCtor>;
    /**
     * @stable [28.10.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [26.05.2019]
     * @returns {JSX.Element}
     */
    render(): JSX.Element;
    /**
     * @stable [29.10.2019]
     */
    componentWillUnmount(): void;
    /**
     * @stable [07.01.2019]
     * @param {AnyT} currentRawValue
     */
    onChangeManually<TValue = AnyT>(currentRawValue: TValue): void;
    /**
     * @stable [18.06.2018]
     * @param {IChangeEvent} event
     * @returns {AnyT}
     */
    getRawValueFromEvent(event: IChangeEvent): AnyT;
    /**
     * @stable [17.06.2018]
     */
    resetError(): void;
    /**
     * @stable [03.09.2018]
     * @param {IKeyboardEvent} event
     */
    onKeyDown(event: IKeyboardEvent): void;
    /**
     * @stable [29.10.2019]
     */
    setFocus(): void;
    /**
     * @stable [28.10.2019]
     * @returns {InputElementT}
     */
    readonly input: InputElementT;
    /**
     * @stable [29.10.2019]
     * @returns {JSX.Element}
     */
    protected getKeyboardElement(): JSX.Element;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    protected readonly selfElement: JSX.Element;
    protected readonly inputWrapperElement: JSX.Element;
    protected readonly labelElement: JSX.Element;
    protected getMirrorInputElement(): JSX.Element;
    protected getInputCaretElement(): JSX.Element;
    protected getAttachmentElement(): JSX.Element;
    /**
     * @stable [28.10.2019]
     * @returns {boolean}
     */
    protected readonly hasInput: boolean;
    /**
     * @stable [20.08.2018]
     */
    protected removeFocus(): void;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [31.08.2018]
     * @returns {JSX.Element}
     */
    protected getInputElement(): JSX.Element;
    /**
     * @stable [30.10.2019]
     * @returns {IFieldComplexInputAttributes}
     */
    protected getInputElementProps(): IFieldComplexInputAttributes;
    /**
     * @stable [06.10.2018]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [23.10.2019]
     * @returns {string}
     */
    protected getInputWrapperElementClassName(): string;
    /**
     * @stable [24.10.2019]
     * @returns {string}
     */
    protected getSelfElementClassName(): string;
    /**
     * @stable [31.07.2018]
     * @returns {boolean}
     */
    protected isInputValid(): boolean;
    /**
     * @stable [31.07.2018]
     * @returns {string}
     */
    protected getNativeInputValidationMessage(): string;
    /**
     * @stable [31.07.2018]
     * @param {string} error
     */
    protected setNativeInputValidity(error: string): void;
    /**
     * @stable [03.09.2018]
     * @param {string} message
     * @param {string} className
     * @returns {JSX.Element}
     */
    protected toMessageElement(message: string, className?: string): JSX.Element;
    /**
     * @stable [30.10.2019]
     * @returns {IFieldActionEntity[]}
     */
    protected getFieldActions(): IFieldActionEntity[];
    /**
     * @stable [17.06.2018]
     * @param {AnyT} value
     */
    private updateInputBeforeHTML5Validation;
    /**
     * @stable [29.09.2019]
     * @returns {IJQueryElement}
     */
    protected readonly jqInput: IJQueryElement;
}
