"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../../../definitions.interface");
var util_1 = require("../../../util");
/**
 * @stable [29.07.2019]
 * @param {MultiFieldSingleValueT} multiFieldEntity
 * @returns {EntityIdT}
 */
exports.toLastAddedMultiItemEntityId = function (multiFieldEntity) {
    return util_1.ifNotNilThanValue(multiFieldEntity, function () { return (util_1.isPrimitive(multiFieldEntity)
        ? multiFieldEntity
        : (util_1.ifNotNilThanValue(multiFieldEntity.add, function (add) { return util_1.ifNotNilThanValue(R.last(add), function (lastValue) { return lastValue.id; }); }))); });
};
/**
 * @stable [04.07.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @returns {EntityIdT[]}
 */
exports.fromMultiFieldEntityToEditedEntitiesIds = function (multiFieldEntity) {
    return fromMultiFieldEntityToEditedEntities(multiFieldEntity, function (entity) { return entity.id; });
};
/**
 * @stable [18.08.2018]
 * @param {MultiFieldEntityT} multiFieldEntity
 * @param {(entity: TItem, index: number) => TResult} mapper
 * @returns {TResult[]}
 */
function fromMultiFieldEntityToEditedEntities(multiFieldEntity, mapper) {
    var result = util_1.asMultiFieldEditedEntities(multiFieldEntity);
    return util_1.orUndef(!R.isNil(result), function () { return result.map(mapper); });
}
exports.fromMultiFieldEntityToEditedEntities = fromMultiFieldEntityToEditedEntities;
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {(value: IMultiEntity) => IMultiItemEntity[]} converter
 * @param {IEntity[]} defaultValue
 * @returns {IMultiItemEntity[] | IEntity[]}
 */
exports.extractMultiItemEntities = function (value, converter, defaultValue) {
    return util_1.isNotMultiEntity(value)
        ? (util_1.isDef(defaultValue)
            ? defaultValue
            : util_1.asEntitiesArray(value))
        : (R.isNil(value) ? [] : converter(value));
};
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IMultiItemEntity[]}
 */
exports.extractMultiEditItemEntities = function (value, defaultValue) {
    if (defaultValue === void 0) { defaultValue = []; }
    return exports.extractMultiItemEntities(value, function (currentValue) { return currentValue.edit; }, defaultValue);
};
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IMultiItemEntity[]}
 */
exports.extractMultiRemoveItemEntities = function (value, defaultValue) {
    if (defaultValue === void 0) { defaultValue = []; }
    return exports.extractMultiItemEntities(value, function (currentValue) { return currentValue.remove; }, defaultValue);
};
/**
 * @stable [02.07.2018]
 * @param {MultiFieldEntityT} value
 * @param {IMultiItemEntity[]} defaultValue
 * @returns {IEntity[]}
 */
exports.extractMultiAddItemEntities = function (value, defaultValue) {
    if (defaultValue === void 0) { defaultValue = []; }
    return exports.extractMultiItemEntities(value, function (currentValue) { return currentValue.add; }, defaultValue);
};
/**
 * @stable [23.06.2018]
 * @param {MultiFieldEntityT} value
 * @param {IEntity[]} defaultValue
 * @returns {IEntity[]}
 */
exports.extractMultiSourceItemEntities = function (value, defaultValue) {
    return exports.extractMultiItemEntities(value, function (currentValue) { return currentValue.source; }, defaultValue);
};
/**
 * @stable [02.07.2018]
 * @param {IEntity | IMultiItemEntity} entity
 * @returns {IEntity}
 */
exports.fromMultiItemEntityToEntity = function (entity) {
    var _a;
    var entityAsMultiItemEntity = entity;
    if (util_1.isDef(entityAsMultiItemEntity.rawData)) {
        return __assign({}, entityAsMultiItemEntity.rawData, (_a = {}, _a[entityAsMultiItemEntity.name] = entityAsMultiItemEntity.value, _a));
    }
    return entity;
};
/**
 * @stable [23.06.2018]
 * @param {string} fieldName
 * @param {MultiFieldEntityT} multiFieldValue
 * @param {(itm: IMultiItemEntity) => boolean} predicate
 * @param {(itm: IMultiItemEntity) => AnyT} nextFieldValueFn
 * @returns {IMultiItemEntity}
 */
exports.buildMultiEditItemEntityPayload = function (fieldName, multiFieldValue, predicate, nextFieldValueFn) {
    var sourceMultiItemEntities = exports.extractMultiSourceItemEntities(multiFieldValue);
    var editedMultiItemEntities = exports.extractMultiEditItemEntities(multiFieldValue);
    var editedMultiItemEntity = editedMultiItemEntities.find(predicate);
    var sourceMultiItemEntity = sourceMultiItemEntities.find(predicate);
    return util_1.buildMultiItemEntity(fieldName, nextFieldValueFn(editedMultiItemEntity, sourceMultiItemEntity), sourceMultiItemEntity);
};
/**
 * @stable [04.07.2018]
 * @param {IMultiItemEntity[]} multiItemEntities
 * @returns {IKeyValue}
 */
exports.fromMultiItemEntitiesToFieldsChanges = function (multiItemEntities) {
    return R.reduceBy(function (acc, entity) {
        var _a;
        return (__assign({}, acc, (_a = {}, _a[entity.name] = entity.value, _a)));
    }, {}, function (entity) { return String(entity.id); }, multiItemEntities);
};
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} first
 * @param {IMultiItemEntity} second
 * @returns {boolean}
 */
exports.isSameEntityByIdAndChangedFieldName = function (first, second) { return (first.id === second.id
    && first.name === second.name); };
/**
 * @stable [11.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
exports.toMultiFieldChangesEntityOnEdit = function (item, addValue, removeValue, editValue, originalValue) {
    var removeArray = removeValue;
    var originalEditedItem = originalValue.find(function (originalItem0) { return originalItem0.id === item.id; });
    var editedNewItem = addValue.find(function (editedNewItem0) { return editedNewItem0.id === item.id; });
    var isEditedNewItem = !R.isNil(editedNewItem);
    var isOriginalEditedItem = !R.isNil(originalEditedItem);
    var editArray = isEditedNewItem
        ? editValue // If a user is editing a new record then returning an input value
        : ( // Otherwise, we should replace an old item with an input item
        editValue
            .filter(function (editedItem) { return !exports.isSameEntityByIdAndChangedFieldName(item, editedItem); })
            .concat(item)
            .filter(function (editedItem) {
            // Need to destroy the dirty changes, if an edited entity attribute is equal an original entity attribute
            return !isOriginalEditedItem
                || !(exports.isSameEntityByIdAndChangedFieldName(item, editedItem) && originalEditedItem[item.name] === item.value);
        }));
    var addArray = isEditedNewItem
        ? (item.value === definitions_interface_1.UNDEF // Need to destroy the added entities
            ? R.filter(function (itm) { return itm.id !== item.id; }, addValue)
            : R.map(function (newItem) { return newItem.id === item.id ? exports.fromMultiItemEntityToEntity(item) : newItem; }, addValue))
        : addValue;
    return { addArray: addArray, removeArray: removeArray, editArray: editArray };
};
/**
 * @stable [18.08.2018]
 * @param {IMultiItemEntity} item
 * @param {IEntity[]} addValue
 * @param {IMultiItemEntity[]} removeValue
 * @param {IMultiItemEntity[]} editValue
 * @param {IEntity[]} originalValue
 * @returns {IMultiFieldChangesEntity}
 */
exports.toMultiFieldChangesEntityOnDelete = function (item, addValue, removeValue, editValue, originalValue) {
    var deletedItemId = item.id;
    var addValueLenBeforeFiltering = addValue.length;
    var editArray = editValue.filter((function (addItem) { return addItem.id !== deletedItemId; }));
    var addArray = addValue.filter((function (addItem) { return addItem.id !== deletedItemId; }));
    var removeArray = removeValue;
    if (addArray.length === addValueLenBeforeFiltering) {
        // The local added items do not contain deleted item
        var deletedEntity = originalValue.find(function (entity) { return entity.id === deletedItemId; });
        removeArray = (R.isNil(deletedEntity) ? [] : [deletedEntity]).concat(removeValue);
    }
    else {
        // We just now have removed deleted item from addValue array
    }
    return { addArray: addArray, removeArray: removeArray, editArray: editArray };
};
/**
 * @stable [07.03.2019]
 * @param {MultiFieldEntityT<TEntity extends IEntity>} multiEntity
 * @param {MultiFieldEntityT<TEntity extends IEntity>} updatedSource
 * @param {(entity: TEntity) => boolean} addFilter
 * @param {(entity: TEntity) => boolean} editFilter
 * @param {(entity: TEntity) => boolean} removeFilter
 * @returns {IMultiEntity}
 */
exports.toFilteredMultiEntity = function (multiEntity, updatedSource, addFilter, editFilter, removeFilter) {
    if (R.isNil(multiEntity) || util_1.isNotMultiEntity(multiEntity)) {
        return definitions_interface_1.UNDEF;
    }
    var multiEntity0 = multiEntity;
    var add = util_1.isFn(addFilter) ? multiEntity0.add.filter(addFilter) : multiEntity0.add;
    var edit = util_1.isFn(editFilter) ? multiEntity0.edit.filter(editFilter) : multiEntity0.edit;
    var remove = util_1.isFn(removeFilter) ? multiEntity0.remove.filter(removeFilter) : multiEntity0.remove;
    if (add.length === 0 && edit.length === 0 && remove.length === 0) {
        return definitions_interface_1.UNDEF;
    }
    return util_1.toType({
        add: add,
        edit: edit,
        remove: remove,
        source: updatedSource,
    });
};
//# sourceMappingURL=multifield.support.js.map