/// <reference types="react" />
import { ILogger } from 'ts-smart-logger';
import { BaseTextField } from '../text-field';
import { AnyT } from '../../../definitions.interface';
import { IBaseSelect, IBaseSelectProps, IBaseSelectState } from './base-select.interface';
import { IBaseEvent, IMenuProps, ISelectOptionEntity } from '../../../definition';
export declare class BaseSelect<TProps extends IBaseSelectProps, TState extends IBaseSelectState> extends BaseTextField<TProps, TState> implements IBaseSelect {
    protected static readonly logger: ILogger;
    private readonly menuRef;
    private readonly quickFilterQueryTask;
    /**
     * @stable [30.11.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    onChange(event: IBaseEvent): void;
    /**
     * @stable [11.01.2020]
     * @param {Readonly<TProps extends IBaseSelectProps>} prevProps
     * @param {Readonly<TState extends IBaseSelectState>} prevState
     */
    componentDidUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>): void;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    onKeyEscape(event: IBaseEvent): void;
    /**
     * @stable [30.11.2019]
     */
    clearValue(): void;
    /**
     * @stable [11.01.2020]
     */
    openMenu(): void;
    /**
     * @stable [16.01.2020]
     * @param {IBaseEvent} event
     */
    onKeyEnter(event: IBaseEvent): void;
    /**
     * @stable [15.01.2020]
     * @returns {boolean}
     */
    protected isFieldBusy(): boolean;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    protected readonly inputAttachmentElement: JSX.Element;
    /**
     * @stable [09.01.2020]
     * @returns {IMenuProps}
     */
    protected getMenuProps(): IMenuProps;
    /**
     * @stable [30.11.2019]
     * @returns {ISelectOptionEntity[]}
     */
    protected readonly filteredOptions: ISelectOptionEntity[];
    /**
     * @stable [11.01.2020]
     * @returns {boolean}
     */
    protected readonly isMenuAlreadyRenderedAndOpened: boolean;
    /**
     * @stable [11.01.2020]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [21.12.2019]
     * @returns {AnyT}
     */
    protected readonly originalEmptyValue: AnyT;
    /**
     * @stable [30.11.2019]
     * @param {ISelectOptionEntity} option
     */
    protected onSelect(option: ISelectOptionEntity): void;
    /**
     * @stable [11.01.2020]
     * @param {ISelectOptionEntity} option
     */
    protected notifySelectOption(option: ISelectOptionEntity): void;
    /**
     * @stable [10.09.2019]
     */
    protected onClose(): void;
    /**
     * @stable [12.02.2019]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected getDecoratedValue(value: AnyT): AnyT;
    /**
     * @stable [11.01.2020]
     * @returns {ISelectOptionEntity[]}
     */
    protected readonly options: ISelectOptionEntity[];
    /**
     * @stable [11.01.2020]
     * @returns {boolean}
     */
    protected readonly isExpandActionRendered: boolean;
    /**
     * @stable [11.01.2020]
     */
    private notifyFilterChange;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    private onDropDownClick;
    private onFilterChange;
    /**
     * @stable [11.01.2020]
     */
    private hideMenu;
    /**
     * @stable [12.01.2020]
     * @param {boolean} force
     */
    private renderAndShowMenu;
    /**
     * @stable [16.01.2020]
     */
    private startQuickSearchIfApplicable;
    /**
     * @stable [11.01.2020]
     * @returns {boolean}
     */
    private readonly isQuickSelectionModeEnabled;
    /**
     * @stable [12.01.2020]
     * @returns {boolean}
     */
    private readonly isWaitingForData;
    /**
     * @stable [24.01.2020]
     * @returns {number}
     */
    private getMenuWidth;
    /**
     * @stable [11.01.2020]
     * @returns {number}
     */
    private readonly delayTimeout;
    /**
     * @stable [15.01.2020]
     * @returns {boolean}
     */
    private readonly areOptionsDefined;
    /**
     * @stable [22.01.2020]
     * @returns {boolean}
     */
    private readonly isMenuRendered;
    /**
     * @stable [24.01.2020]
     * @returns {boolean}
     */
    private readonly isMenuAnchored;
    /**
     * @stable [24.01.2020]
     * @returns {HTMLElement}
     */
    private getMenuAnchorElement;
    /**
     * @stable [30.11.2019]
     * @returns {IMenu}
     */
    private readonly menu;
}
