/// <reference types="react" />
/// <reference types="googlemaps" />
import { BaseComponent } from '../../base';
import { IGoogleMaps, IGoogleMapsHeatMapLayerConfigEntity, IGoogleMapsMarkerConfigEntity, IGoogleMapsMenuContextEntity, IGoogleMapsProps } from '../../../definition';
export declare class GoogleMaps extends BaseComponent<IGoogleMapsProps> implements IGoogleMaps, IGoogleMapsMenuContextEntity {
    lat: number;
    lng: number;
    x: number;
    y: number;
    private clickEventListener;
    private dbClickEventListener;
    private googleMapsLibTask;
    private heatMapLayer;
    private map;
    private markers;
    private markersListeners;
    private openMenuTask;
    private readonly menuRef;
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsProps} props
     */
    constructor(props: IGoogleMapsProps);
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    render(): JSX.Element;
    /**
     * @stable [09.01.2020]
     */
    componentDidMount(): void;
    /**
     * @stable [22.01.2020]
     */
    componentWillUnmount(): void;
    /**
     * @stable [22.01.2020]
     * @param {google.maps.MarkerOptions} cfg
     * @param {string} name
     * @returns {google.maps.Marker}
     */
    addMarker(cfg?: google.maps.MarkerOptions, name?: string): google.maps.Marker;
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsMarkerConfigEntity} cfg
     */
    setMarkerState(cfg: IGoogleMapsMarkerConfigEntity): void;
    /**
     * @stable [04.03.2019]
     * @param {IGoogleMapsHeatMapLayerConfigEntity} cfg
     */
    addHeatMapLayer(cfg: IGoogleMapsHeatMapLayerConfigEntity): void;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    private readonly menuElement;
    /**
     * @stable [10.01.2020]
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     */
    private onMarkerDragEnd;
    /**
     * @stable [10.01.2020]
     * @param {IMenuItemEntity} item
     */
    private onMenuSelect;
    /**
     * @stable [22.01.2020]
     * @param {IGoogleMapsEventClickPayloadEntity} event
     */
    private onMapClick;
    /**
     * @stable [23.01.2020]
     * @param {IGoogleMapsEventClickPayloadEntity} event
     */
    private onMapDbClick;
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsMenuContextEntity} context
     */
    private openMenu;
    /**
     * @stable [22.01.2020]
     */
    private onGoogleMapsReady;
    /**
     * @stable [04.03.2019]
     * @param {ILatLngEntity} latLng
     * @param {number} zoom
     */
    private refreshMap;
    /**
     * @stable [09.01.2020]
     */
    private cancelGoogleMapsLibTask;
    /**
     * @stable [22.01.2020]
     */
    private unbindListeners;
    /**
     * @stable [23.01.2020]
     * @returns {boolean}
     */
    private readonly haveMenuOptions;
    /**
     * @stable [04.03.2019]
     * @returns {IGoogleMapsSettingsEntity}
     */
    private readonly mapsSettings;
    /**
     * @stable [10.01.2020]
     * @returns {IMenu}
     */
    private readonly menu;
}
