"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var base_1 = require("../../base");
var menu_1 = require("../../menu");
var util_1 = require("../../../util");
var definition_1 = require("../../../definition");
var GoogleMaps = /** @class */ (function (_super) {
    __extends(GoogleMaps, _super);
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsProps} props
     */
    function GoogleMaps(props) {
        var _this = _super.call(this, props) || this;
        _this.markers = new Map();
        _this.markersListeners = new Map();
        _this.menuRef = React.createRef();
        _this.addHeatMapLayer = _this.addHeatMapLayer.bind(_this);
        _this.onGoogleMapsReady = _this.onGoogleMapsReady.bind(_this);
        _this.onMapClick = _this.onMapClick.bind(_this);
        _this.onMapDbClick = _this.onMapDbClick.bind(_this);
        _this.onMenuSelect = _this.onMenuSelect.bind(_this);
        _this.openMenu = _this.openMenu.bind(_this);
        if (_this.haveMenuOptions) {
            _this.openMenuTask = new util_1.DelayedTask(_this.openMenu, 200); // Double click issue
        }
        return _this;
    }
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    GoogleMaps.prototype.render = function () {
        var props = this.props;
        return (React.createElement("div", { className: util_1.joinClassName('rac-google-maps', props.className) },
            React.createElement("div", { ref: this.selfRef, className: 'rac-google-maps__body' }),
            this.menuElement));
    };
    /**
     * @stable [09.01.2020]
     */
    GoogleMaps.prototype.componentDidMount = function () {
        var _this = this;
        _super.prototype.componentDidMount.call(this);
        this.googleMapsLibTask = this.asyncLibManager
            .waitForLib({ alias: definition_1.AsyncLibsEnum.GOOGLE_MAPS })
            .then(function () { return _this.onGoogleMapsReady(); });
    };
    /**
     * @stable [22.01.2020]
     */
    GoogleMaps.prototype.componentWillUnmount = function () {
        var _this = this;
        _super.prototype.componentWillUnmount.call(this);
        util_1.ifNotNilThanValue(this.openMenuTask, function (task) {
            task.stop();
            _this.openMenuTask = null;
        });
        this.cancelGoogleMapsLibTask();
        this.unbindListeners();
        this.markers = null;
        this.markersListeners = null;
    };
    /**
     * @stable [22.01.2020]
     * @param {google.maps.MarkerOptions} cfg
     * @param {string} name
     * @returns {google.maps.Marker}
     */
    GoogleMaps.prototype.addMarker = function (cfg, name) {
        var _this = this;
        var config = __assign({ anchorPoint: new google.maps.Point(0, -29), position: null }, cfg, { map: this.map });
        var markerId = name || util_1.uuid();
        var marker = new google.maps.Marker(config);
        this.markers.set(markerId, marker);
        if (config.draggable) {
            this.markersListeners.set(markerId, google.maps.event.addListener(marker, 'dragend', function () { return _this.onMarkerDragEnd(markerId, marker); }));
        }
        return marker;
    };
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsMarkerConfigEntity} cfg
     */
    GoogleMaps.prototype.setMarkerState = function (cfg) {
        var marker = cfg.marker, _a = cfg.visible, visible = _a === void 0 ? true : _a, refreshMap = cfg.refreshMap, _b = cfg.lat, lat = _b === void 0 ? this.mapsSettings.lat : _b, _c = cfg.lng, lng = _c === void 0 ? this.mapsSettings.lng : _c, _d = cfg.zoom, zoom = _d === void 0 ? this.mapsSettings.zoom : _d;
        var markerAsObject = util_1.isString(marker)
            ? this.markers.get(marker)
            : marker;
        markerAsObject.setPosition({ lat: lat, lng: lng });
        markerAsObject.setVisible(visible);
        if (refreshMap) {
            this.refreshMap({ lat: lat, lng: lng }, zoom);
        }
    };
    /**
     * @stable [04.03.2019]
     * @param {IGoogleMapsHeatMapLayerConfigEntity} cfg
     */
    GoogleMaps.prototype.addHeatMapLayer = function (cfg) {
        var points = cfg.points;
        var isArrayOfPointsNotEmpty = util_1.isArrayNotEmpty(points);
        if (isArrayOfPointsNotEmpty) {
            this.heatMapLayer = new google.maps.visualization.HeatmapLayer({
                map: this.map,
                data: points.map(function (point) { return new google.maps.LatLng(point.lat, point.lng); }),
            });
        }
        if (cfg.refreshMap) {
            this.refreshMap(isArrayOfPointsNotEmpty ? points[0] : this.mapsSettings, util_1.nvl(cfg.zoom, this.mapsSettings.zoom));
        }
    };
    Object.defineProperty(GoogleMaps.prototype, "menuElement", {
        /**
         * @stable [22.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            return util_1.orNull(this.haveMenuOptions, function () { return (React.createElement(menu_1.Menu, { ref: _this.menuRef, xPosition: function () { return _this.x + _this.getSelf().offsetLeft; }, yPosition: function () { return _this.y + _this.getSelf().offsetTop; }, options: props.menuOptions, onSelect: _this.onMenuSelect })); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [10.01.2020]
     * @param {string} markerId
     * @param {google.maps.Marker} marker
     */
    GoogleMaps.prototype.onMarkerDragEnd = function (markerId, marker) {
        var position = marker.getPosition();
        var lat = position.lat();
        var lng = position.lng();
        var props = this.props;
        if (util_1.isFn(props.onChangePlace)) {
            props.onChangePlace({ name: markerId, item: marker, lat: lat, lng: lng });
        }
    };
    /**
     * @stable [10.01.2020]
     * @param {IMenuItemEntity} item
     */
    GoogleMaps.prototype.onMenuSelect = function (item) {
        var props = this.props;
        if (util_1.isFn(props.onSelect)) {
            props.onSelect({ item: item, lat: this.lat, lng: this.lng });
        }
    };
    /**
     * @stable [22.01.2020]
     * @param {IGoogleMapsEventClickPayloadEntity} event
     */
    GoogleMaps.prototype.onMapClick = function (event) {
        var _this = this;
        var props = this.props;
        util_1.ifNotNilThanValue(event.pixel, function (pixel) {
            var x = pixel.x;
            var y = pixel.y;
            var lat = event.latLng.lat();
            var lng = event.latLng.lng();
            util_1.ifNotNilThanValue(_this.openMenuTask, function (openMenuTask) { return openMenuTask.start({ x: x, y: y, lat: lat, lng: lng }); });
        });
        if (util_1.isFn(props.onClick)) {
            props.onClick(event);
        }
    };
    /**
     * @stable [23.01.2020]
     * @param {IGoogleMapsEventClickPayloadEntity} event
     */
    GoogleMaps.prototype.onMapDbClick = function (event) {
        util_1.ifNotNilThanValue(this.openMenuTask, function (openMenuTask) { return openMenuTask.stop(); });
    };
    /**
     * @stable [10.01.2020]
     * @param {IGoogleMapsMenuContextEntity} context
     */
    GoogleMaps.prototype.openMenu = function (context) {
        Object.assign(this, context);
        this.menu.show();
    };
    /**
     * @stable [22.01.2020]
     */
    GoogleMaps.prototype.onGoogleMapsReady = function () {
        var props = this.props;
        var _a = props.options, options = _a === void 0 ? {} : _a;
        // google.maps.MapTypeId enum is loaded as a lazy resource (within a lazy loaded script)
        var mapTypes = new Map();
        mapTypes.set(definition_1.GoogleMapsMapTypeEnum.SATELLITE, google.maps.MapTypeId.SATELLITE);
        mapTypes.set(definition_1.GoogleMapsMapTypeEnum.HYBRID, google.maps.MapTypeId.HYBRID);
        mapTypes.set(definition_1.GoogleMapsMapTypeEnum.TERRAIN, google.maps.MapTypeId.TERRAIN);
        this.unbindListeners();
        this.map = new google.maps.Map(this.getSelf(), __assign({}, options, { mapTypeId: mapTypes.get(options.mapTypeId) || google.maps.MapTypeId.ROADMAP }));
        this.clickEventListener = google.maps.event.addListener(this.map, 'click', this.onMapClick);
        this.dbClickEventListener = google.maps.event.addListener(this.map, 'dblclick', this.onMapDbClick);
        if (util_1.isFn(props.onInit)) {
            props.onInit(this.map);
        }
    };
    /**
     * @stable [04.03.2019]
     * @param {ILatLngEntity} latLng
     * @param {number} zoom
     */
    GoogleMaps.prototype.refreshMap = function (latLng, zoom) {
        this.map.setCenter({ lat: latLng.lat, lng: latLng.lng });
        this.map.setZoom(zoom);
    };
    /**
     * @stable [09.01.2020]
     */
    GoogleMaps.prototype.cancelGoogleMapsLibTask = function () {
        this.asyncLibManager.cancelWaiting(this.googleMapsLibTask);
        this.googleMapsLibTask = null;
    };
    /**
     * @stable [22.01.2020]
     */
    GoogleMaps.prototype.unbindListeners = function () {
        var _this = this;
        this.markersListeners.forEach(function (listener) { return listener.remove(); });
        this.markersListeners.clear();
        this.markers.forEach(function (marker) { return marker.unbindAll(); });
        this.markers.clear();
        util_1.ifNotNilThanValue(this.clickEventListener, function (listener) {
            listener.remove();
            _this.clickEventListener = null;
        });
        util_1.ifNotNilThanValue(this.dbClickEventListener, function (listener) {
            listener.remove();
            _this.dbClickEventListener = null;
        });
        util_1.ifNotNilThanValue(this.heatMapLayer, function (heatMapLayer) {
            heatMapLayer.unbindAll();
            _this.heatMapLayer = null;
        });
        util_1.ifNotNilThanValue(this.map, function (map) {
            map.unbindAll();
            _this.map = null;
        });
    };
    Object.defineProperty(GoogleMaps.prototype, "haveMenuOptions", {
        /**
         * @stable [23.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isObjectNotEmpty(this.props.menuOptions);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GoogleMaps.prototype, "mapsSettings", {
        /**
         * @stable [04.03.2019]
         * @returns {IGoogleMapsSettingsEntity}
         */
        get: function () {
            return this.settings.googleMaps;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GoogleMaps.prototype, "menu", {
        /**
         * @stable [10.01.2020]
         * @returns {IMenu}
         */
        get: function () {
            return this.menuRef.current;
        },
        enumerable: true,
        configurable: true
    });
    return GoogleMaps;
}(base_1.BaseComponent));
exports.GoogleMaps = GoogleMaps;
//# sourceMappingURL=google-maps.component.js.map