"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../util");
var list_1 = require("../list");
var field_1 = require("../field");
var field_2 = require("../field");
var flex_1 = require("../layout/flex");
var column_1 = require("./column");
var header_1 = require("./header");
var row_1 = require("./row");
var grid_support_1 = require("./grid.support");
var Grid = /** @class */ (function (_super) {
    __extends(Grid, _super);
    /**
     * @stable [07.06.2018]
     * @param {IGridProps} props
     */
    function Grid(props) {
        var _this = _super.call(this, props) || this;
        _this.onExpandAllGroups = _this.onExpandAllGroups.bind(_this);
        _this.state = { filterChanges: {}, expandedGroups: {}, expandedAllGroups: false };
        return _this;
    }
    /**
     * @stable [23.10.2019]
     * @returns {JSX.Element}
     */
    Grid.prototype.getView = function () {
        var _this = this;
        var props = this.props;
        var dataSource = this.dataSource;
        return (React.createElement("div", { className: util_1.joinClassName('rac-grid-wrapper', props.wrapperClassName) },
            React.createElement("table", { cellPadding: 0, cellSpacing: 0, className: util_1.joinClassName('rac-grid', props.className) },
                util_1.isHeaderRendered(props) && (React.createElement(header_1.GridHeader, { stickyHead: props.stickyHead },
                    this.headRowElement,
                    this.filterElement)),
                React.createElement("tbody", { className: 'rac-grid-body' },
                    props.topTotal !== false && this.totalRowElement,
                    this.isGrouped
                        ? this.getGroupedRows(dataSource)
                        : dataSource.map(function (entity, rowNum) { return _this.getRow({ entity: entity, rowNum: rowNum, highlightOdd: util_1.isHighlightOdd(props, rowNum) }); }),
                    props.topTotal === false && this.totalRowElement))));
    };
    /**
     * @stable [07.06.2018]
     * @returns {IEntity[]}
     */
    Grid.prototype.filterAndSortOriginalDataSourceUsingLocalFiltersAndSorters = function () {
        return grid_support_1.filterAndSortGridOriginalDataSource(this.originalDataSource, this.columnsConfiguration, this.props, this.state);
    };
    /**
     * @stable [06.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeRowField = function (payload) {
        var props = this.props;
        if (props.onChange) {
            props.onChange(payload);
        }
    };
    /**
     * @stable [07.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeGroupingRowField = function (payload) {
        var props = this.props;
        if (props.onChangeBoolValue) {
            props.onChangeBoolValue(payload);
        }
    };
    /**
     * @stable [07.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeHeaderField = function (payload) {
        var props = this.props;
        if (props.onChangeHeader) {
            props.onChangeHeader(payload);
        }
    };
    /**
     * @stable [07.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeFilterField = function (payload) {
        var _a;
        var props = this.props;
        if (props.localFiltration) {
            this.setState({
                filterChanges: __assign({}, this.state.filterChanges, (_a = {}, _a[payload.name] = payload.value, _a)),
            });
        }
        else if (props.onChangeFilter) {
            props.onChangeFilter(payload);
        }
    };
    /**
     * @stable - 06.04.2018
     * @param {IGridColumnProps} column
     * @param {number} columnNum
     * @returns {React.ReactNode}
     */
    Grid.prototype.getHeaderColumnContent = function (column, columnNum) {
        var _this = this;
        if (column.bool) {
            var name_1 = this.toHeaderFieldName(columnNum);
            return (React.createElement(field_1.Checkbox, __assign({}, this.getDefaultFieldProps(), { name: name_1, value: this.toCheckboxFieldValue(name_1), onChange: function (value) { return _this.onChangeHeaderField({ value: value, name: name_1 }); } })));
        }
        else if (util_1.isFn(column.headerRenderer)) {
            return column.headerRenderer(column);
        }
        return this.t(column.title);
    };
    Object.defineProperty(Grid.prototype, "headRowElement", {
        get: function () {
            var _this = this;
            var expandedAllGroups = this.state.expandedAllGroups;
            var expandActionRendered = this.isExpandActionRendered;
            var _a = this, isGrouped = _a.isGrouped, props = _a.props;
            return (React.createElement(row_1.GridRow, null, this.columnsConfiguration.map(function (column, columnNum) { return (React.createElement(header_1.GridHeaderColumn, __assign({ key: _this.toHeaderColumnKey(columnNum) }, grid_support_1.getGridColumnSortDirection(column, _this.props), { name: column.name, index: columnNum, onSortingDirectionChange: function (payload) {
                    return props.onSortingDirectionChange(__assign({}, payload, { index: columnNum, multi: false }));
                } }, column), // TODO (duplication)
            expandActionRendered && isGrouped && columnNum === 0 // TODO index 0 (duplication)
                ? _this.uiFactory.makeIcon({
                    key: "header-" + columnNum + "-expanded-action-" + (expandedAllGroups ? 'close' : 'open'),
                    className: 'rac-grid-data-row-group-expanded-icon',
                    type: expandedAllGroups ? 'close-list' : 'open-list',
                    onClick: _this.onExpandAllGroups,
                })
                : _this.getHeaderColumnContent(column, columnNum))); })));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [07.06.2018]
     * @param {IEntity} entity
     * @param {IGridColumnProps} column
     * @param {number} columnNum
     * @param {number} rowNum
     * @param {IEntity[]} groupedRows
     * @returns {React.ReactNode}
     */
    Grid.prototype.getColumn = function (entity, column, columnNum, rowNum, groupedRows) {
        var _this = this;
        var name = this.toFieldName(entity, column, columnNum);
        if (column.bool) {
            return (React.createElement(field_1.Checkbox, __assign({}, this.getDefaultFieldProps(), { name: name, value: this.toCheckboxFieldValue(name), onChange: function (value) { return _this.onChangeGroupingRowField({ value: value, name: name, rawData: entity }); } })));
        }
        else if (column.tpl) {
            return column.tpl(entity, column, rowNum);
        }
        else if (column.renderer) {
            var renderEl = column.renderer(entity, column, groupedRows);
            if (R.isNil(renderEl)) {
                return renderEl;
            }
            if (this.isElementField(renderEl)) {
                var props = renderEl.props;
                var propsValue = props.value;
                return React.cloneElement(renderEl, __assign({}, this.getDefaultFieldProps(props), { name: column.name, keepChanges: true, value: util_1.isDef(propsValue) ? propsValue : Reflect.get(entity, column.name), onChange: function (value) { return _this.onChangeRowField({ value: value, name: name, rawData: entity }); } }));
            }
            return renderEl;
        }
        else if (column.name) {
            return Reflect.get(entity, column.name);
        }
        return null;
    };
    /**
     * @stable [07.06.2018]
     * @param {IGridColumnProps} column
     * @param {number} columnNum
     * @returns {React.ReactNode}
     */
    Grid.prototype.getFilterColumn = function (column, columnNum) {
        var _this = this;
        if (column.filterRenderer) {
            /**
             * Build using a renderer
             */
            var renderEl = column.filterRenderer(column);
            if (R.isNil(renderEl)) {
                return renderEl;
            }
            if (this.isElementField(renderEl)) {
                var name_2 = this.toFilterFieldName(column, columnNum);
                return React.cloneElement(renderEl, {
                    value: this.toFilterFieldValue(name_2),
                    placeholder: 'Filter',
                    clearActionRendered: true,
                    errorMessageRendered: false,
                    onChange: function (value) { return _this.onChangeFilterField({ value: value, name: name_2 }); },
                });
            }
            return renderEl;
        }
        return null;
    };
    /**
     * @stable [06.12.2019]
     * @param {IGridRowConfigEntity} rowConfig
     * @returns {JSX.Element}
     */
    Grid.prototype.getRow = function (rowConfig) {
        var _this = this;
        var props = this.props;
        var entity = rowConfig.entity, groupedRows = rowConfig.groupedRows, highlightOdd = rowConfig.highlightOdd, rowNum = rowConfig.rowNum;
        var rowKey = this.toRowKey(entity);
        var entityChanges = props.changes[entity.id];
        var hasChanges = !R.isNil(entityChanges);
        var isPartOfGroup = !R.isNil(groupedRows);
        return (React.createElement(row_1.GridRow, { key: rowKey, odd: highlightOdd, hovered: util_1.isHovered(props), selected: this.isEntitySelected(entity), selectable: util_1.isSelectable(props), entity: entity, partOfGroup: isPartOfGroup, onClick: props.onSelect }, this.columnsConfiguration.map(function (column, columnNum) { return (React.createElement(column_1.GridColumn, __assign({ index: columnNum, edited: hasChanges && column.name in entityChanges, entity: entity }, column, { key: rowKey + "-" + columnNum }), _this.getColumn(entity, column, columnNum, rowNum, groupedRows))); })));
    };
    Object.defineProperty(Grid.prototype, "filterElement", {
        /**
         * @stable [26.10.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var columns = this.columnsConfiguration;
            return (util_1.orNull(columns.some(function (column) { return util_1.isFn(column.filterRenderer); }), function () { return (React.createElement(row_1.GridRow, { filter: true }, columns.map(function (column, columnNum) { return (React.createElement(header_1.GridHeaderColumn, __assign({ key: _this.toFilterColumnKey(columnNum), index: columnNum }, column), _this.getFilterColumn(column, columnNum))); }))); }));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [07.06.2018]
     * @param {string} name
     * @returns {AnyT}
     */
    Grid.prototype.toFilterFieldValue = function (name) {
        var props = this.props;
        var state = this.state;
        return util_1.orUndef(props.localFiltration, function () { return state.filterChanges[name]; });
    };
    /**
     * @stable [07.06.2018]
     * @returns {IFieldProps}
     */
    Grid.prototype.getDefaultFieldProps = function (fieldProps) {
        return {
            errorMessageRendered: false,
            readOnly: (fieldProps && fieldProps.readOnly) || this.props.deactivated,
        };
    };
    /**
     * @stable [07.06.2018]
     * @param {IEntity} entity
     * @param {IGridColumnProps} column
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toFieldName = function (entity, column, columnNum) {
        return column.name || "$$dynamic-field-" + entity.id + "-" + columnNum; // Infinity scroll supporting
    };
    /**
     * @stable [07.06.2018]
     * @param {IGridColumnProps} column
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toFilterFieldName = function (column, columnNum) {
        return column.name || "$$dynamic-filter-field-" + columnNum;
    };
    /**
     * @stable - 06.04.2018
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toHeaderFieldName = function (columnNum) {
        return "$$dynamic-header-field-" + columnNum;
    };
    /**
     * @stable - 05.04.2018
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toFilterColumnKey = function (columnNum) {
        return "grid-filter-column-" + columnNum;
    };
    /**
     * @stable - 05.04.2018
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toHeaderColumnKey = function (columnNum) {
        return "grid-header-column-" + columnNum;
    };
    /**
     * @stable - 06.04.2018
     * @param {string} fieldName
     * @returns {AnyT}
     */
    Grid.prototype.toFieldValue = function (fieldName) {
        return this.props.changes[fieldName];
    };
    /**
     * @stable - 06.04.2018
     * @param {string} fieldName
     * @returns {AnyT}
     */
    Grid.prototype.toCheckboxFieldValue = function (fieldName) {
        var fieldValue = this.toFieldValue(fieldName);
        return util_1.isDef(fieldValue) ? fieldValue : false;
    };
    /**
     * @stable [07.06.2018]
     * @param {JSX.Element} renderEl
     * @returns {boolean}
     */
    Grid.prototype.isElementField = function (renderEl) {
        return field_2.Field.isPrototypeOf(renderEl.type);
    };
    Object.defineProperty(Grid.prototype, "columnsConfiguration", {
        /**
         * @stable [10.10.2018]
         * @returns {IGridColumnProps[]}
         */
        get: function () {
            return R.filter(function (column) { return column.rendered !== false; }, this.props.columnsConfiguration);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [04.07.2018]
     * @param {EntityIdT} groupedRowValue
     * @returns {string}
     */
    Grid.prototype.toGroupedRowKey = function (groupedRowValue) {
        return "data-grouped-row-" + groupedRowValue;
    };
    /**
     * @stable [27.12.2018]
     * @returns {string}
     */
    Grid.prototype.toTotalRowKey = function () {
        return "data-total-row";
    };
    /**
     * @stable [05.10.2018]
     * @param {EntityIdT} groupedRowValue
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toGroupedColumnKey = function (groupedRowValue, columnNum) {
        return "data-grouped-column-" + groupedRowValue + "-" + columnNum;
    };
    /**
     * @stable [27.12.2018]
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toTotalColumnKey = function (columnNum) {
        return "data-total-column-" + columnNum;
    };
    /**
     * @stable [06.09.2018]
     * @param {IEntity[]} dataSource
     * @returns {JSX.Element[]}
     */
    Grid.prototype.getGroupedRows = function (dataSource) {
        var _this = this;
        if (R.isEmpty(dataSource)) {
            return [];
        }
        var props = this.props;
        var groupedDataSorter = props.groupedDataSorter;
        var preparedDataSource = util_1.isFn(groupedDataSorter)
            ? R.sort(function (entity1, entity2) {
                return groupedDataSorter(_this.extractGroupFieldValue(entity1), _this.extractGroupFieldValue(entity2), entity1, entity2);
            }, dataSource)
            : dataSource;
        var groupedDataSourceMap = new Map();
        var groupValuesSet = new Set(); // To save original ordering
        var isGroupedByReadyData = this.isGroupedByReadyData;
        preparedDataSource.forEach(function (entity) {
            var groupedDataSourceEntities;
            var groupFieldValue = _this.extractGroupFieldValue(entity);
            if (isGroupedByReadyData) {
                groupValuesSet.add(entity.id);
                groupedDataSourceMap.set(entity.id, groupFieldValue);
            }
            else {
                /**
                 * See https://www.ecma-international.org/ecma-262/6.0/#sec-set-objects
                 * ...Append value as the last element of entries.
                 *
                 * See https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Set/add
                 * The add() method appends a new element with a specified value to the end of a Set object.
                 */
                groupValuesSet.add(groupFieldValue);
                groupedDataSourceEntities = groupedDataSourceMap.get(groupFieldValue);
                if (!groupedDataSourceMap.has(groupFieldValue)) {
                    groupedDataSourceMap.set(groupFieldValue, groupedDataSourceEntities = []);
                }
                groupedDataSourceEntities.push(entity);
            }
        });
        var groupingRowNum = 0;
        var rows = [];
        // See the comment at the top
        groupValuesSet.forEach(function (groupValue) {
            var groupedRows = groupedDataSourceMap.get(groupValue);
            var highlightOdd = util_1.isHighlightOdd(props, groupingRowNum++);
            rows.push(_this.getGroupingRow({ value: groupValue, groupedRows: groupedRows, highlightOdd: highlightOdd }));
            if (_this.isGroupedRowExpanded(groupValue)) {
                groupedRows.forEach(function (entity, rowNum) { return rows.push(_this.getRow({ entity: entity, rowNum: rowNum, groupedRows: groupedRows, highlightOdd: highlightOdd })); });
            }
        });
        return rows;
    };
    /**
     * @stable [06.12.2019]
     * @param {IGridRowConfigEntity} config
     * @returns {JSX.Element}
     */
    Grid.prototype.getGroupingRow = function (config) {
        var _this = this;
        var props = this.props;
        var value = config.value, groupedRows = config.groupedRows, highlightOdd = config.highlightOdd;
        var groupBy = props.groupBy;
        var groupValue = groupBy.groupValue;
        var isGroupValueArray = Array.isArray(groupValue);
        var isExpanded = this.isGroupedRowExpanded(value);
        var expandActionRendered = this.isExpandActionRendered;
        var columns = this.columnsConfiguration;
        return (React.createElement(row_1.GridRow, { key: this.toGroupedRowKey(value), grouped: true, odd: highlightOdd, groupExpanded: isExpanded }, columns.map(function (column, columnNum) {
            var key = _this.toGroupedColumnKey(value, columnNum);
            var contentKey = _this.toGroupedColumnKey(value + "-content", columnNum);
            var node = (columnNum === 0
                ? (React.createElement(flex_1.FlexLayout, { row: true, full: false, key: contentKey },
                    expandActionRendered && (_this.uiFactory.makeIcon({
                        key: contentKey + "-expanded-action-" + (isExpanded ? 'close' : 'open'),
                        className: 'rac-grid-data-row-group-expanded-icon',
                        type: isExpanded ? 'close-list' : 'open-list',
                        onClick: function () { return _this.onExpandGroup(value, !isExpanded); },
                    })),
                    " ",
                    util_1.isFn(groupValue)
                        ? groupValue(value, groupedRows)
                        : (isGroupValueArray
                            ? (util_1.isFn(groupValue[0]) ? groupValue[0](value, groupedRows) : null)
                            : value)))
                : (util_1.orNull(isGroupValueArray && util_1.isFn(groupValue[columnNum]), function () { return groupValue[columnNum](value, groupedRows); })));
            return (React.createElement(column_1.GridColumn, __assign({ key: key }, column), node));
        })));
    };
    Object.defineProperty(Grid.prototype, "totalRowElement", {
        /**
         * @stable [27.10.2019]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return util_1.ifNotNilThanValue(this.props.totalEntity, function (totalEntity) { return (React.createElement(row_1.GridRow, { key: _this.toTotalRowKey(), total: true }, _this.columnsConfiguration.map(function (column, columnNum) { return (React.createElement(column_1.GridColumn, __assign({ key: _this.toTotalColumnKey(columnNum) }, column), totalEntity[column.name])); }))); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [29.12.2019]
     * @param {EntityIdT} groupedRowValue
     * @param {boolean} expanded
     */
    Grid.prototype.onExpandGroup = function (groupedRowValue, expanded) {
        this.setState(function (previousState) {
            var _a;
            return ({ expandedGroups: __assign({}, previousState.expandedGroups, (_a = {}, _a[groupedRowValue] = expanded, _a)) });
        });
    };
    /**
     * @stable [29.12.2019]
     */
    Grid.prototype.onExpandAllGroups = function () {
        this.setState(function (previousState) { return ({ expandedAllGroups: !previousState.expandedAllGroups, expandedGroups: {} }); });
    };
    /**
     * @stable [03.09.2018]
     * @param {EntityIdT} groupedRowValue
     * @returns {boolean}
     */
    Grid.prototype.isGroupedRowExpanded = function (groupedRowValue) {
        var state = this.state;
        var props = this.props;
        return util_1.coalesce(util_1.ifNotNilThanValue(state.expandedGroups, function (expandedGroups) { return expandedGroups[groupedRowValue]; }), util_1.ifNotNilThanValue(props.expandedGroups, function (expandedGroups) { return expandedGroups[groupedRowValue]; }), state.expandedAllGroups);
    };
    /**
     * @stable [29.12.2019]
     * @param {IEntity} entity
     * @returns {AnyT}
     */
    Grid.prototype.extractGroupFieldValue = function (entity) {
        var groupBy = this.props.groupBy;
        return Reflect.get(entity, groupBy.groupedFieldName || groupBy.fieldName);
    };
    Object.defineProperty(Grid.prototype, "isGrouped", {
        /**
         * @stable [29.12.2019]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isDef(this.props.groupBy);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Grid.prototype, "isGroupedByReadyData", {
        /**
         * @stable [29.12.2019]
         * @returns {boolean}
         */
        get: function () {
            return this.isGrouped && util_1.isDef(this.props.groupBy.groupedFieldName);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Grid.prototype, "isExpandActionRendered", {
        /**
         * @stable [27.10.2019]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isExpandActionRendered(this.props);
        },
        enumerable: true,
        configurable: true
    });
    return Grid;
}(list_1.BaseList));
exports.Grid = Grid;
//# sourceMappingURL=grid.component.js.map