"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var ts_smart_logger_1 = require("ts-smart-logger");
var universal_component_1 = require("../base/universal.component");
var util_1 = require("../../util");
var definition_1 = require("../../definition");
var KeyInterceptor = /** @class */ (function (_super) {
    __extends(KeyInterceptor, _super);
    /**
     * @stable [05.05.2018]
     * @param props
     */
    function KeyInterceptor(props) {
        var _this = _super.call(this, props) || this;
        _this.buffer = definition_1.FIELD_DISPLAY_EMPTY_VALUE;
        _this.onEventCapture = _this.onEventCapture.bind(_this);
        _this.delayedTask = new util_1.DelayedTask(_this.onCheckBuffer.bind(_this), props.delayTimeout);
        return _this;
    }
    /**
     * @stable [05.05.2018]
     */
    KeyInterceptor.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        this.unSubscriber = this.eventManager.subscribe(this.environment.document, this.captureEvent, this.onEventCapture);
    };
    /**
     * @stable [05.05.2018]
     */
    KeyInterceptor.prototype.componentWillUnmount = function () {
        this.delayedTask.stop();
        if (util_1.isFn(this.unSubscriber)) {
            this.unSubscriber();
            this.unSubscriber = null;
        }
        _super.prototype.componentWillUnmount.call(this);
    };
    /**
     * @stable [08.10.2019]
     * @returns {JSX.Element}
     */
    KeyInterceptor.prototype.render = function () {
        return null;
    };
    /**
     * @stable [08.10.2019]
     * @param {KeyboardEvent} e
     */
    KeyInterceptor.prototype.onEventCapture = function (e) {
        if (this.domAccessor.isAlreadyFocused()) {
            // Don't interfere with normal input typings
            return;
        }
        var keyCode = e.keyCode;
        if (KeyInterceptor.SPECIAL_KEY_CODES.includes(keyCode)) {
            return;
        }
        var props = this.props;
        var char = e.key;
        if (KeyInterceptor.ENTER_KEY_CODES.includes(keyCode)) {
            if (props.ignoreEnterKey) {
                KeyInterceptor.logger.debug('[$KeyInterceptor][onEventCapture] Ignore enter key code and exit.');
                return;
            }
            char = '\n';
        }
        this.buffer = "" + this.buffer + char;
        this.delayedTask.start();
    };
    /**
     * @stable [08.10.2019]
     */
    KeyInterceptor.prototype.onCheckBuffer = function () {
        var props = this.props;
        if (this.buffer.length >= props.robotDetectionMinSymbolsCount) {
            var onSelect = props.onSelect;
            if (util_1.isFn(onSelect)) {
                var normalizedValue = this.buffer.trim(); // Normalize a buffer in some specific case (production issue fix (!))
                onSelect(normalizedValue);
            }
        }
        this.buffer = definition_1.FIELD_DISPLAY_EMPTY_VALUE;
    };
    Object.defineProperty(KeyInterceptor.prototype, "captureEvent", {
        /**
         * @stable [11.09.2019]
         * @returns {string}
         */
        get: function () {
            // iOS Safari doesn't support space key at least
            // keypress -> keydown
            // https://developer.mozilla.org/en-US/docs/Web/API/Document/keypress_event
            // Since this event has been deprecated, you should look to use beforeinput or keydown instead.
            return this.isCaptureFilterDisabled
                ? KeyInterceptor.IOS_SAFARI_CAPTURE_EVENT
                : KeyInterceptor.DEFAULT_CAPTURE_EVENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyInterceptor.prototype, "isCaptureFilterDisabled", {
        /**
         * @stable [08.10.2019]
         * @returns {boolean}
         */
        get: function () {
            return this.environment.safariOrSafariMobilePlatform && this.environment.iosPlatform;
        },
        enumerable: true,
        configurable: true
    });
    KeyInterceptor.defaultProps = {
        delayTimeout: 300,
        robotDetectionMinSymbolsCount: 3,
    };
    KeyInterceptor.logger = ts_smart_logger_1.LoggerFactory.makeLogger('KeyInterceptor');
    KeyInterceptor.IOS_SAFARI_CAPTURE_EVENT = definition_1.EventsEnum.KEY_DOWN;
    KeyInterceptor.DEFAULT_CAPTURE_EVENT = definition_1.EventsEnum.KEY_PRESS;
    KeyInterceptor.ENTER_KEY_CODES = [10, 13];
    KeyInterceptor.SPECIAL_KEY_CODES = [
        8,
        9,
        16,
        17,
        18 // alt
    ];
    return KeyInterceptor;
}(universal_component_1.UniversalComponent));
exports.KeyInterceptor = KeyInterceptor;
//# sourceMappingURL=key-interceptor.component.js.map