"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var ts_smart_logger_1 = require("ts-smart-logger");
var definition_1 = require("../../definition");
var util_1 = require("../../util");
var FieldConverter = /** @class */ (function () {
    /**
     * @stable [09.01.2020]
     */
    function FieldConverter() {
        this.converters = new Map();
        this.register({
            from: definition_1.FieldConverterTypesEnum.GEO_CODER_RESULT,
            to: definition_1.FieldConverterTypesEnum.PLACE_ENTITY,
            converter: util_1.asPlaceEntity,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.PLACE_ENTITY,
            to: definition_1.FieldConverterTypesEnum.STRING,
            converter: util_1.asPlaceEntityFormattedName,
        });
        this.register({
            from: definition_1.FieldConverterTypesEnum.PLACE_ENTITY,
            to: definition_1.FieldConverterTypesEnum.PLACE_PARAMETER,
            converter: util_1.asPlaceParameter,
        });
    }
    FieldConverter_1 = FieldConverter;
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     */
    FieldConverter.prototype.register = function (config) {
        this.converters.set(this.asKey(config), config.converter);
        FieldConverter_1.logger.debug("[$FieldConverter][register] The converter has been registered successfully:", config);
    };
    /**
     * @stable [24.12.2019]
     * @param {IPhoneConfigEntity<libphonenumber.PhoneNumberFormat>} config
     * @returns {string}
     */
    FieldConverter.prototype.convert = function (config) {
        var value = config.value;
        var converter = this.converter(config);
        if (!util_1.isFn(converter)) {
            throw new Error("The converter is not registered! A config " + JSON.stringify(config) + ":");
        }
        return converter(value);
    };
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {(value: AnyT) => AnyT}
     */
    FieldConverter.prototype.converter = function (config) {
        return this.converters.get(this.asKey(config));
    };
    /**
     * @stable [09.01.2020]
     * @param {IFieldConverterConfigEntity} config
     * @returns {string}
     */
    FieldConverter.prototype.asKey = function (config) {
        return config.from + "-" + config.to;
    };
    var FieldConverter_1;
    FieldConverter.logger = ts_smart_logger_1.LoggerFactory.makeLogger('FieldConverter');
    FieldConverter = FieldConverter_1 = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], FieldConverter);
    return FieldConverter;
}());
exports.FieldConverter = FieldConverter;
//# sourceMappingURL=field-converter.service.js.map