/// <reference types="googlemaps" />
import { IItemWrapper, IMarkerWrapper, IMenuOptionsWrapper, INameWrapper, IOnChangePlaceWrapper, IOnClickWrapper, IOnInitWrapper, IOnSelectWrapper, IOptionsWrapper, IPointsWrapper, IRefreshMapWrapper, IVisibleWrapper, IZoomWrapper } from '../definitions.interface';
import { ILatLngEntity } from './place-definition.interface';
import { IMenuItemEntity } from './menu-definition.interface';
import { IXYEntity } from './xy-definition.interface';
import { IComponentProps } from './props-definition.interface';
/**
 * @entity
 * @stable [09.01.2020]
 */
export interface IGoogleMapsMenuItemEntity extends IItemWrapper<IMenuItemEntity>, ILatLngEntity {
}
/**
 * @config-entity
 * @stable [09.01.2020]
 */
export interface IGoogleMapsMarkerConfigEntity extends ILatLngEntity, IMarkerWrapper<string | google.maps.Marker>, IRefreshMapWrapper, IVisibleWrapper, IZoomWrapper {
}
/**
 * @config-entity
 * @stable [09.01.2020]
 */
export interface IGoogleMapsHeatMapLayerConfigEntity extends IPointsWrapper<ILatLngEntity[]>, IRefreshMapWrapper, IZoomWrapper {
}
/**
 * @entity
 * @stable [23.01.2020]
 */
export interface IGoogleMapsMarkerChangePlaceEntity extends ILatLngEntity, INameWrapper, IItemWrapper<google.maps.Marker> {
}
/**
 * @entity
 * @stable [10.01.2020]
 */
export interface IGoogleMapsMenuContextEntity extends ILatLngEntity, IXYEntity {
}
/**
 * @external-entity
 * @stable [03.03.2019]
 */
export interface IGoogleMapsEventClickPayloadEntity {
    pixel?: google.maps.Point;
    latLng?: google.maps.LatLng;
}
/**
 * @enum
 * @stable [04.03.2019]
 */
export declare enum GoogleMapsMapTypeEnum {
    HYBRID = 0,
    ROADMAP = 1,
    SATELLITE = 2,
    TERRAIN = 3
}
/**
 * @generic-entity
 * @stable [23.01.2020]
 */
export interface IGenericGoogleMapsEntity extends IOptionsWrapper<google.maps.MapOptions>, IMenuOptionsWrapper<IMenuItemEntity[]> {
}
/**
 * @behavioral-entity
 * @stable [23.01.2020]
 */
export interface IBehavioralGoogleMapsEntity extends IOnChangePlaceWrapper<IGoogleMapsMarkerChangePlaceEntity>, IOnClickWrapper<IGoogleMapsEventClickPayloadEntity>, IOnInitWrapper, IOnSelectWrapper<IGoogleMapsMenuItemEntity> {
}
/**
 * @props
 * @stable [23.01.2020]
 */
export interface IGoogleMapsProps extends IComponentProps, IGenericGoogleMapsEntity, IBehavioralGoogleMapsEntity {
}
/**
 * @component
 * @stable [09.01.2020]
 */
export interface IGoogleMaps {
    addHeatMapLayer(cfg: IGoogleMapsHeatMapLayerConfigEntity): void;
    addMarker(cfg?: google.maps.MarkerOptions, name?: string): google.maps.Marker;
    setMarkerState(cfg: IGoogleMapsMarkerConfigEntity): void;
}
