import { IUpdateEntityPayloadEntity, IEnvironment } from '../definition';
import { EntityIdT, IEntity } from '../definitions.interface';
import { INumberConverter } from '../converter';
import { ISettingsEntity } from '../settings';
import { IFieldConverter, IPlaceEntity, ITransport, ITransportRequestEntity, MultiFieldEntityT } from '../definition';
export declare class BaseTransport {
    protected readonly environment: IEnvironment;
    protected readonly nc: INumberConverter;
    protected readonly settings: ISettingsEntity;
    protected readonly transport: ITransport;
    protected readonly fieldConverter: IFieldConverter;
    /**
     * @stable [29.08.2019]
     * @param {StringNumberT} value
     * @param {(value: number) => number} converter
     * @returns {number}
     */
    protected prepareNumberValue: (value: string | number, converter?: (value: number) => number) => number;
    /**
     * @stable [10.01.2020]
     * @param {IPlaceEntity} value
     * @returns {string}
     */
    protected preparePlaceParameterValue: (value: IPlaceEntity<string>) => string;
    /**
     * @stable [16.12.2019]
     * @param {string} value
     * @returns {string}
     */
    protected prepareCronValue: (value: string) => string;
    /**
     * @stable [13.10.2019]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected prepareStringValue: (value: any) => any;
    /**
     * @stable [25.07.2019]
     * @param {string} value
     * @returns {string}
     */
    protected preparePhoneValue(value: string): string;
    /**
     * @stable [26.12.2019]
     * @param {MultiFieldEntityT | EntityIdT[]} value
     * @returns {EntityIdT[]}
     */
    protected prepareMultiEntitiesIdsValue(value: MultiFieldEntityT | EntityIdT[]): EntityIdT[];
    /**
     * @stable [31.08.2019]
     * @param {ITransportRequestEntity} params
     */
    protected downloadFile(params: ITransportRequestEntity): void;
    /**
     * @stable [23.12.2019]
     * @param {IUpdateEntityPayloadEntity<TEntity extends IEntity>} entity
     * @returns {Promise<TResult>}
     */
    protected doSaveEntity<TEntity extends IEntity, TResult = TEntity>(entity: IUpdateEntityPayloadEntity<TEntity>): Promise<TResult>;
}
