import { IJQueryElement, IXYEntity } from '../definition';
/**
 * @stable [28.08.2019]
 * @param {string} id
 * @returns {TElement}
 */
export declare const getElementById: <TElement extends HTMLElement = HTMLElement>(id: string) => TElement;
/**
 * @stable [14.06.2018]
 * @param {string} tag
 * @param {Element} parent
 * @returns {TElement}
 */
export declare const createElement: <TElement extends HTMLElement = HTMLElement>(tag?: string, parent?: Element) => TElement;
/**
 * @stable [08.01.2020]
 * @param {Partial<HTMLScriptElement>} cfg
 * @returns {Promise<HTMLScriptElement>}
 */
export declare const createScript: (cfg: Partial<HTMLScriptElement>) => Promise<HTMLScriptElement>;
/**
 * @stable [30.07.2018]
 * @param {Element} element
 * @param {string} clsName
 */
export declare const addClassNames: (element: Element, ...clsName: string[]) => void;
/**
 * @stable [30.10.2018]
 * @param {Element} element
 * @param {string} clsName
 */
export declare const removeClassNames: (element: Element, ...clsName: string[]) => void;
/**
 * @stable [20.09.2019]
 * @param {string} rootId
 * @returns {Element}
 */
export declare const addRootElement: (rootId: string) => Element;
/**
 * @stable [14.11.2018]
 * @param {string} clsName
 */
export declare const addClassNameToBody: (...clsName: string[]) => void;
/**
 * @stable [28.06.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
export declare const addChild: (child: Element, parent?: Element) => Element;
/**
 * @stable [28.06.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
export declare const removeChild: (child: Element, parent?: Element) => Element;
/**
 * @stable [17.11.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
export declare const removeSelf: (child: Element, parent?: Element) => Element;
/**
 * @stable [14.06.2018]
 * @param {string} images
 */
export declare const createPreloadedImg: (...images: string[]) => void;
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getWidth: (source: Element) => number;
/**
 * @stable [27.10.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getHeight: (source: Element) => number;
/**
 * @stable [27.10.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getContentHeight: (source: Element) => number;
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getScrollLeft: (source: Element) => number;
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getScrollTop: (source: Element) => number;
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @param {number} value
 * @returns {IJQueryElement}
 */
export declare const setScrollTop: (source: Element, value: number) => IJQueryElement<Element>;
/**
 * @stable [18.12.2018]
 * @param {Element} source
 * @param {number} value
 * @returns {IJQueryElement}
 */
export declare const setScrollLeft: (source: Element, value: number) => IJQueryElement<Element>;
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @returns {boolean}
 */
export declare const isParentDocumentBody: (source: Element) => boolean;
/**
 * @stable [23.06.2018]
 * @returns {boolean}
 */
export declare const isDocumentHasFocus: () => boolean;
/**
 * @stable [13.12.2018]
 * @param {Element} source
 * @returns {IJQueryElement}
 */
export declare const toJqEl: <TJqElement extends IJQueryElement<Element> = IJQueryElement<Element>>(source: Element) => TJqElement;
/**
 * @stable [30.08.2019]
 * @param {string} url
 * @param {string} fileName
 */
export declare const downloadFileAsBlobUrl: (url: string, fileName?: string) => void;
/**
 * @stable [30.08.2019]
 * @param {string} url
 * @param {string} fileName
 */
export declare const downloadFile: (url: string, fileName?: string) => Promise<void>;
/**
 * @stable [30.08.2019]
 * @param {Blob} blob
 * @param {string} fileName
 */
export declare const downloadFileAsBlob: (blob: Blob, fileName?: string) => void;
/**
 * @stable [19.09.2018]
 * @param {string} v
 * @returns {number}
 */
export declare const parseValueAtPx: (v: string) => number;
/**
 * @stable [30.07.2018]
 * @returns {() => boolean}
 */
export declare const preventContextMenu: () => () => boolean;
/**
 * @stable [16.02.2019]
 * @param {string | Element} selector
 * @param {Element} parent
 * @returns {TJqElement}
 */
export declare const findElements: <TJqElement extends IJQueryElement<Element> = IJQueryElement<Element>>(selector: string | Element, parent?: Element) => TJqElement;
/**
 * @stable [16.02.2019]
 * @param {string | Element} selector
 * @param {Element} parent
 * @returns {TJqElement}
 */
export declare const findElement: (selector: string | Element, parent?: Element) => Element;
/**
 * @stable [08.02.2019]
 * @param {string} selector
 * @param {Element} target
 * @returns {TJqElement}
 */
export declare const getParents: <TJqElement extends IJQueryElement<Element> = IJQueryElement<Element>>(selector: string, target: Element) => TJqElement;
/**
 * @stable [08.02.2019]
 * @param {string} selector
 * @param {Element} target
 * @returns {boolean}
 */
export declare const hasParent: (selector: string, target: Element) => boolean;
/**
 * @stable [22.10.2019]
 * @param {Element} target
 * @param {string} classNames
 * @returns {boolean}
 */
export declare const hasClasses: (target: Element, ...classNames: string[]) => boolean;
/**
 * @stable [16.02.2019]
 * @param {string | Element} selector
 * @param {Element} target
 * @returns {boolean}
 */
export declare const hasElements: (selector: string | Element, target: Element) => boolean;
/**
 * @stable [01.12.2018]
 * @param {Element} element
 * @param {IXYEntity} xyEntity
 */
export declare const scrollTo: (element: Element, xyEntity: IXYEntity) => void;
/**
 * @stable [26.10.2019]
 * @param {Element} element
 * @param {Element} parent
 * @returns {boolean}
 */
export declare const isElementVisibleWithinParent: (element: Element, parent: Element) => boolean;
/**
 * @stable [11.10.2019]
 * @param {Element} stickyWrapperEl
 * @param {string} stickySelector
 * @param {(stickyJEl: IJQueryElement) => any} widthResolver
 */
export declare const setStickyElementProperties: (stickyWrapperEl: Element, stickySelector: string, widthResolver?: (stickyJEl: IJQueryElement<Element>) => number) => void;
/**
 * @stable [03.04.2019]
 * @param {Element & {mozRequestFullScreen?: () => void; msRequestFullscreen?: () => void}} elem
 */
export declare const openFullScreen: (elem: Element & {
    mozRequestFullScreen?: () => void;
    msRequestFullscreen?: () => void;
}) => void;
