"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var filter_1 = require("./filter");
var field_definition_interface_1 = require("../definition/field-definition.interface");
var definitions_interface_1 = require("../definitions.interface");
describe('util/filter', function () {
    describe('filterByPredicate', function () {
        it('test1', function () {
            var filteredObject = filter_1.filterByPredicate({
                key1: 'value1',
                key2: 'value2',
            }, function (key, value) { return key !== 'key1'; });
            expect(filteredObject).toEqual({
                key2: 'value2',
            });
        });
        it('test2', function () {
            var filteredObject = filter_1.filterByPredicate({
                key1: 'value1',
                key2: 'value2',
            }, function (key, value) { return key !== 'key3'; });
            expect(filteredObject).toEqual({
                key1: 'value1',
                key2: 'value2',
            });
        });
        it('test3', function () {
            var filteredObject = filter_1.filterByPredicate({
                key1: 'value1',
                key2: 'value2',
            }, function (key, value) { return key !== 'key2'; }, function (key, value) { return key !== 'key1'; });
            expect(filteredObject).toEqual({});
        });
        it('test4', function () {
            var filteredObject = filter_1.filterByPredicate({
                key1: 'value1',
                key2: 'value2',
            }, function (key, value) { return key !== 'key1'; }, function (key, value) { return key !== 'key3'; });
            expect(filteredObject).toEqual({
                key2: 'value2',
            });
        });
    });
    describe('excludeFieldsFilter', function () {
        it('test1', function () {
            var filteredObject = filter_1.excludeFieldsFilter({
                key1: 'value1',
                key2: 'value2',
            }, 'key1');
            expect(filteredObject).toEqual({
                key2: 'value2',
            });
        });
        it('test2', function () {
            var filteredObject = filter_1.excludeFieldsFilter({
                key1: 'value1',
                key2: 'value2',
            }, 'key1', 'key2');
            expect(filteredObject).toEqual({});
        });
        it('test3', function () {
            var filteredObject = filter_1.excludeFieldsFilter({
                key1: 'value1',
                key2: 'value2',
            }, 'key3');
            expect(filteredObject).toEqual({
                key1: 'value1',
                key2: 'value2',
            });
        });
    });
    describe('defValuesFilter', function () {
        it('test1', function () {
            var filteredObject = filter_1.defValuesFilter({
                key1: 'value1',
                key2: void 0,
            });
            expect(filteredObject).toEqual({
                key1: 'value1',
            });
        });
        it('test2', function () {
            var filteredObject = filter_1.defValuesFilter({
                key1: 'value1',
                key2: 100,
            });
            expect(filteredObject).toEqual({
                key1: 'value1',
                key2: 100,
            });
        });
        it('test3', function () {
            var filteredObject = filter_1.defValuesFilter({
                key1: 'value1',
                key2: null,
                key3: 0,
            });
            expect(filteredObject).toEqual({
                key1: 'value1',
                key2: null,
                key3: 0,
            });
        });
    });
    describe('excludeIdFieldFilter', function () {
        it('test1', function () {
            var _a;
            var filteredObject = filter_1.excludeIdFieldFilter((_a = {
                    key1: 'value1'
                },
                _a[field_definition_interface_1.ID_FIELD_NAME] = 100,
                _a));
            expect(filteredObject).toEqual({
                key1: 'value1',
            });
        });
        it('test2', function () {
            var filteredObject = filter_1.excludeIdFieldFilter({ id1: 'value1' });
            expect(filteredObject).toEqual({
                id1: 'value1',
            });
        });
    });
    describe('cloneUsingFilters', function () {
        it('test1', function () {
            var o = { key1: 'value1', key2: { key3: 'value3' } };
            var clonedObject = filter_1.cloneUsingFilters(o);
            expect(clonedObject).toEqual({ key1: 'value1', key2: { key3: 'value3' } });
        });
        it('test2', function () {
            var o = { key1: 'value1', key2: { key3: 'value3' } };
            var clonedObject = filter_1.cloneUsingFilters(o);
            Reflect.set(clonedObject, 'key4', 'value4');
            expect(o).toEqual({ key1: 'value1', key2: { key3: 'value3' } });
        });
        it('test3', function () {
            var o = { key1: 'value1', key2: { key3: 'value3' } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key3'; });
            expect(clonedObject).toEqual({ key1: 'value1', key2: {} });
        });
        it('test4', function () {
            var o = { key1: 'value1', key2: { key3: 'value3' } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key2'; });
            expect(clonedObject).toEqual({ key1: 'value1' });
        });
        it('test5', function () {
            var o = { key1: 'value1', key2: [1, 2, 3] };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key2'; });
            expect(clonedObject).toEqual({ key1: 'value1' });
        });
        it('test6', function () {
            var o = { key1: 'value1', key2: { key3: null } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key3'; });
            expect(clonedObject).toEqual({ key1: 'value1', key2: {} });
        });
        it('test7', function () {
            var o = { key1: 'value1', key2: { key3: definitions_interface_1.UNDEF } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key3'; });
            expect(clonedObject).toEqual({ key1: 'value1', key2: {} });
        });
        it('test8', function () {
            var o = { key1: 'value1', key2: { key3: 0 } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key3'; });
            expect(clonedObject).toEqual({ key1: 'value1', key2: {} });
        });
        it('test9', function () {
            var o = {};
            var clonedObject = filter_1.cloneUsingFilters(o);
            expect(clonedObject).toEqual({});
        });
        it('test10', function () {
            var o = { key1: 'value1', key2: { key3: new Date() } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key3'; });
            expect(clonedObject).toEqual({ key1: 'value1', key2: {} });
        });
        it('test11', function () {
            var o = { key1: 'value1', key2: { key3: { key4: { key3: 'value3' } }, key7: { key8: null, key9: null } } };
            var clonedObject = filter_1.cloneUsingFilters(o, function (key) { return key !== 'key3' && key !== 'key9'; });
            expect(clonedObject).toEqual({ key1: 'value1', key2: { key7: { key8: null } } });
        });
    });
    describe('cloneUsingTimeFieldsFilters', function () {
        it('test1', function () {
            var _a, _b, _c;
            var o = (_a = {
                    key1: 'value1'
                },
                _a[definitions_interface_1.TIME_FIELD_NAME] = '10:59:59',
                _a[definitions_interface_1.FROM_TIME_FIELD_NAME] = '10:59:59',
                _a[definitions_interface_1.TO_TIME_FIELD_NAME] = '10:59:59',
                _a.key2 = (_b = {
                        key3: 'value3'
                    },
                    _b[definitions_interface_1.TIME_FIELD_NAME] = '10:59:59',
                    _b[definitions_interface_1.FROM_TIME_FIELD_NAME] = '10:59:59',
                    _b[definitions_interface_1.TO_TIME_FIELD_NAME] = '10:59:59',
                    _b.key4 = (_c = {
                            key5: 'value5'
                        },
                        _c[definitions_interface_1.TIME_FIELD_NAME] = '10:59:59',
                        _c[definitions_interface_1.FROM_TIME_FIELD_NAME] = '10:59:59',
                        _c[definitions_interface_1.TO_TIME_FIELD_NAME] = '10:59:59',
                        _c),
                    _b),
                _a);
            var clonedObject = filter_1.cloneUsingTimeFieldsFilters(o);
            expect(clonedObject).toEqual({
                key1: 'value1',
                key2: {
                    key3: 'value3',
                    key4: {
                        key5: 'value5',
                    },
                },
            });
        });
    });
});
//# sourceMappingURL=filter.spec.js.map