import { IEffectsAction } from 'redux-effects-promise';
import { IDictionaryEntity, IEditableEntity, IExtendedEntity, IFormExtendedEditableEntity, IListEntity, IListWrapperEntity, IOperationEntity, IOptionEntity, IPagedEntity, IPaginatedEntity, IPreviousActionWrapperEntity, IQueryFilterEntity, IQueryFilterWrapperEntity, ISelectOptionEntity, ISortDirectionEntity, ISortDirectionsEntity, ISortDirectionsWrapperEntity, IStackEntity, IStackItemEntity, IStackWrapperEntity, ITabPanelEntity, ITabPanelWrapperEntity, ITransportEntity, ITransportWrapperEntity, IUniversalApplicationEntity, IUserEntity, IUserWrapperEntity, ToolbarToolsEnum, IApiEntity } from '../definition';
import { IActionsDisabledWrapper, IDisabledWrapper, IEntity, IEntityIdTWrapper, IKeyValue, IPreventEffectsWrapper, IProgressWrapper, IQueryWrapper, IQueueWrapper, IRawDataWrapper, ISelectedWrapper, ITokenWrapper } from '../definitions.interface';
/**
 * @stable [17.11.2019]
 * @param {ITokenWrapper} entity
 * @returns {StringNumberT}
 */
export declare const selectToken: (entity: ITokenWrapper<string>) => string;
/**
 * @stable [25.11.2019]
 * @param {IQueueWrapper<TValue>} entity
 * @returns {TValue}
 */
export declare const selectQueue: <TValue>(entity: IQueueWrapper<TValue>) => TValue;
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
export declare const selectTransportWrapperToken: (entity: ITransportWrapperEntity) => string;
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string[]}
 */
export declare const selectTransportWrapperQueue: (entity: ITransportWrapperEntity) => string[];
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {ITransportEntity}
 */
export declare const selectTransport: (entity: ITransportWrapperEntity) => ITransportEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
export declare const selectEntityId: (entity: IEntityIdTWrapper) => string | number;
/**
 * @stable [04.09.2019]
 * @param {IFormExtendedEditableEntity<TEntity extends IEntity>} entity
 * @returns {IEditableEntity<TEntity extends IEntity>}
 */
export declare const selectEditableEntity: <TEntity extends IEntity = IEntity>(entity: IFormExtendedEditableEntity<TEntity>) => IEditableEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult extends IEntity = IEntity>(entity: IEditableEntity<IKeyValue>) => TResult;
/**
 * @stable [20.12.2019]
 * @param {IEditableEntity} entity
 * @returns {TResult}
 */
export declare const selectDefaultChanges: <TResult extends IEntity = IEntity>(entity: IEditableEntity<IKeyValue>) => TResult;
/**
 * @stable [21.11.2019]
 * @param {IFormExtendedEditableEntity<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
export declare const selectEditableEntityChanges: <TEntity extends IEntity = IEntity>(entity: IFormExtendedEditableEntity<TEntity>) => TEntity;
/**
 * @stable [19.10.2019]
 * @param {IListWrapperEntity<TEntity extends IEntity>} entity
 * @returns {IListEntity<TEntity extends IEntity>}
 */
export declare const selectListEntity: <TEntity extends IEntity = IEntity>(entity: IListWrapperEntity<TEntity>) => IListEntity<TEntity, any>;
/**
 * @stable [18.10.2019]
 * @param {IListEntity} entity
 * @returns {ISortDirectionsEntity}
 */
export declare const selectListEntityDirections: (entity: IListEntity<IEntity, any>) => ISortDirectionsEntity;
/**
 * @stable [28.09.2019]
 * @param {IUserWrapperEntity} entity
 * @returns {IUserEntity}
 */
export declare const selectUserEntity: (entity: IUserWrapperEntity) => IUserEntity;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryFilterEntity}
 */
export declare const selectQueryFilterEntity: (entity: IQueryFilterWrapperEntity) => IQueryFilterEntity;
/**
 * @stable [19.10.2019]
 * @param {IQueryWrapper} entity
 * @returns {string}
 */
export declare const selectQuery: (entity: IQueryWrapper<string>) => string;
/**
 * @stable [27.11.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
export declare const selectFilterQuery: (entity: IQueryFilterWrapperEntity) => string;
/**
 * @stable [19.10.2019]
 * @param {ISelectedWrapper<TEntity extends IEntity>} listEntity
 * @returns {TEntity}
 */
export declare const selectSelectedEntity: <TEntity extends IEntity>(listEntity: ISelectedWrapper<TEntity>) => TEntity;
/**
 * @stable [19.01.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectSelectedEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [19.01.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
export declare const selectSelectedEntityIdFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => string | number;
/**
 * @stable [20.10.2019]
 * @param {IPreviousActionWrapperEntity} data
 * @returns {IEffectsAction}
 */
export declare const selectPreviousAction: (data: IPreviousActionWrapperEntity) => IEffectsAction;
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {IEffectsAction}
 */
export declare const selectPreviousActionFromAction: (action: IEffectsAction) => IEffectsAction;
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {string}
 */
export declare const selectPreviousActionTypeFromAction: (action: IEffectsAction) => string;
/**
 * @stable [20.10.2019]
 * @param {IPreventEffectsWrapper} data
 * @returns {boolean}
 */
export declare const selectPreventEffects: (data: IPreventEffectsWrapper<boolean>) => boolean;
/**
 * @stable [20.10.2019]
 * @param {IEffectsAction} action
 * @returns {boolean}
 */
export declare const selectPreventEffectsFromAction: (action: IEffectsAction) => boolean;
/**
 * @stable [19.01.2020]
 * @param {IEffectsAction} action
 * @returns {TData}
 */
export declare const selectDataFromAction: <TData>(action: IEffectsAction) => TData;
/**
 * @stable [19.01.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
export declare const selectDataPayloadFromAction: <TPayload>(action: IEffectsAction) => TPayload;
/**
 * @stable [19.10.2019]
 * @param {IRawDataWrapper<TData>} listEntity
 * @returns {TData}
 */
export declare const selectListRawDataEntity: <TData = any>(listEntity: IRawDataWrapper<TData>) => TData;
/**
 * @stable [21.11.2019]
 * @param {ITabPanelWrapperEntity} entity
 * @returns {ITabPanelEntity}
 */
export declare const selectTabPanelEntity: (entity: ITabPanelWrapperEntity) => ITabPanelEntity;
/**
 * @stable [18.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TData}
 */
export declare const selectListWrapperRawDataEntity: <TData = any>(listWrapperEntity: IListWrapperEntity<IEntity>) => TData;
/**
 * @stable [19.10.2019]
 * @param {IListWrapperEntity<TEntity extends IEntity>} listWrapperEntity
 * @returns {TEntity}
 */
export declare const selectListSelectedEntity: <TEntity extends IEntity>(listWrapperEntity: IListWrapperEntity<TEntity>) => TEntity;
/**
 * @stable [30.08.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {string}
 */
export declare const selectFilterWrapperQuery: (entity: IQueryFilterWrapperEntity) => string;
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
export declare const mapEntityId: (id: string | number) => IEntityIdTWrapper;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionsEntity} directions
 * @returns {ISortDirectionsWrapperEntity}
 */
export declare const mapSortDirectionsWrapperEntity: (directions: ISortDirectionsEntity) => ISortDirectionsWrapperEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
export declare const mapIdentifiedEntity: (entity: IEntityIdTWrapper) => IEntityIdTWrapper;
/**
 * @stable [21.11.2019]
 * @param {ITabPanelEntity} tabPanel
 * @returns {ITabPanelWrapperEntity}
 */
export declare const mapTabPanelEntity: (tabPanel: ITabPanelEntity) => ITabPanelWrapperEntity;
/**
 * @stable [21.11.2019]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
export declare const mapTabPanelWrapperEntity: (tabPanelWrapperEntity: ITabPanelWrapperEntity) => ITabPanelWrapperEntity;
/**
 * @stable [28.09.2019]
 * @param {IUserEntity} user
 * @returns {IUserWrapperEntity}
 */
export declare const mapUserEntity: (user: IUserEntity) => IUserWrapperEntity;
/**
 * @stable [12.10.2019]
 * @param {boolean} disabled
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabled: (disabled: boolean) => IDisabledWrapper<boolean>;
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
export declare const mapQuery: (query: string) => IQueryWrapper<string>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterEntity} filter
 * @returns {IQueryFilterWrapperEntity}
 */
export declare const mapQueryFilterEntity: (filter: IQueryFilterEntity) => IQueryFilterWrapperEntity;
/**
 * @stable [21.11.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} form
 * @returns {IFormExtendedEditableEntity<TEntity extends IEntity>}
 */
export declare const mapEditableEntity: <TEntity extends IEntity = IEntity>(form: IEditableEntity<TEntity>) => IFormExtendedEditableEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IListEntity} list
 * @returns {IListWrapperEntity}
 */
export declare const mapListEntity: (list: IListEntity<IEntity, any>) => IListWrapperEntity<IEntity>;
/**
 * @stable [10.09.2019]
 * @param {IPagedEntity} entity
 * @returns {IPagedEntity}
 */
export declare const mapPagedEntity: (entity: IPagedEntity) => IPagedEntity;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
export declare const mapSortDirectionEntity: (entity: ISortDirectionEntity) => ISortDirectionEntity;
/**
 * @stable [04.10.2019]
 * @param {IListEntity} entity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
export declare const mapListPagedEntity: (entity: IListEntity<IEntity, any>, pageSize?: number) => IPagedEntity;
/**
 * @stable [12.10.2019]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabledProgressWrapper: (entity: IProgressWrapper) => IDisabledWrapper<boolean>;
/**
 * @stable [12.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabledProgressListWrapperEntity: (listWrapperEntity: IListWrapperEntity<IEntity>) => IDisabledWrapper<boolean>;
/**
 * @stable [04.10.2019]
 * @param {IListWrapperEntity} entity
 * @param {number} pageSize
 * @returns {IPagedEntity}
 */
export declare const mapListWrapperPagedEntity: (entity: IListWrapperEntity<IEntity>, pageSize?: number) => IPagedEntity;
/**
 * @stable [10.09.2019]
 * @param {IPaginatedEntity} entity
 * @returns {IPaginatedEntity}
 */
export declare const mapPaginatedEntity: (entity: IPaginatedEntity) => IPaginatedEntity;
/**
 * @stable [04.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IListWrapperEntity}
 */
export declare const mapListWrapperEntity: (listWrapper: IListWrapperEntity<IEntity>) => IListWrapperEntity<IEntity>;
/**
 * @stable [28.09.2019]
 * @param {IUserWrapperEntity} userWrapper
 * @returns {IUserWrapperEntity}
 */
export declare const mapUserWrapperEntity: (userWrapper: IUserWrapperEntity) => IUserWrapperEntity;
/**
 * @stable [21.12.2019]
 * @param {TEntity} entity
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapExtendedEntity: <TEntity extends IEntity = IEntity>(entity: TEntity, editableEntity: IEditableEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [25.12.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapExtendedEditableEntity: <TEntity extends IEntity = IEntity>(editableEntity: IEditableEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} extendedEntity
 * @returns {IApiEntity<TEntity extends IEntity>}
 */
export declare const mapApiEntity: <TEntity extends IEntity = IEntity>(extendedEntity: IExtendedEntity<TEntity>) => IApiEntity<TEntity>;
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapListSelectedExtendedEntity: <TEntity extends IEntity>(listWrapper: IListWrapperEntity<TEntity>, editableEntity: IEditableEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterWrapperEntity} queryFilter
 * @returns {IQueryFilterWrapperEntity}
 */
export declare const mapQueryFilterWrapperEntity: (queryFilter: IQueryFilterWrapperEntity) => IQueryFilterWrapperEntity;
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterWrapperEntity} entity
 * @returns {IQueryWrapper}
 */
export declare const mapFilterWrapperQuery: (entity: IQueryFilterWrapperEntity) => IQueryWrapper<string>;
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapActionsDisabled: (actionsDisabled: boolean) => IActionsDisabledWrapper;
/**
 * @stable [17.09.2019]
 * @param {IListEntity} list
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapListActionsDisabled: (list: IListEntity<IEntity, any>) => IActionsDisabledWrapper;
/**
 * @stable [17.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @returns {}
 */
export declare const mapListWrapperActionsDisabled: (listWrapper: IListWrapperEntity<IEntity>) => IActionsDisabledWrapper;
/**
 * @stable [11.10.2019]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
export declare const mapSelectOptions: <TEntity extends IOptionEntity>(data: TEntity | TEntity[]) => ISelectOptionEntity<TEntity>[];
/**
 * @stable [18.09.2019]
 * @param {IEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectEditableEntityToolbarToolsActiveFilter: (editableEntity: IEditableEntity<IKeyValue>) => ToolbarToolsEnum[];
/**
 * @stable [18.09.2019]
 * @param {IFormExtendedEditableEntity} fEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectFormEntityToolbarToolsActiveFilter: (fEntity: IFormExtendedEditableEntity<IEntity>) => ToolbarToolsEnum[];
/**
 * @stable [11.10.2019]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => TResult} accessor
 * @returns {TEntity[] | TEntity | TResult}
 */
export declare const mapDictionaryEntityData: <TEntity, TResult = TEntity | TEntity[]>(dictionaryEntity: IDictionaryEntity<TEntity>, accessor?: (data: TEntity | TEntity[]) => TResult) => TEntity | TResult | TEntity[];
/**
 * @stable [11.10.2019]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @returns {Array<ISelectOptionEntity<TDictionaryEntity>>}
 */
export declare const mapDictionaryEntity: <TDictionaryEntity>(dictionaryEntity: IDictionaryEntity<TDictionaryEntity>) => ISelectOptionEntity<TDictionaryEntity>[];
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasQueueOperations: (queue: string[], ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasTransportWrapperQueueOperations: (entity: ITransportWrapperEntity, ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationInProgress: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const doesApplicationErrorExist: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationMessageVisible: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackEntity}
 */
export declare const selectStackEntity: (entity: IStackWrapperEntity) => IStackEntity;
/**
 * @stable [18.12.2019]
 * @param {IStackEntity} entity
 * @returns {IStackItemEntity[]}
 */
export declare const selectStackItemEntities: (entity: IStackEntity) => IStackItemEntity[];
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackItemEntity[]}
 */
export declare const selectStackWrapperItemEntities: (entity: IStackWrapperEntity) => IStackItemEntity[];
