"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var cond_1 = require("./cond");
var type_1 = require("./type");
var calc_1 = require("./calc");
/**
 * @stable [24.10.2019]
 * @param {IValidWrapper} validEntity
 * @returns {boolean}
 */
exports.isValid = function (validEntity) {
    return cond_1.ifNotNilThanValue(validEntity, function () { return validEntity.valid !== false; }, false);
};
/**
 * @stable [22.01.2020]
 * @param {IFieldRenderedWrapper} validEntity
 * @returns {boolean}
 */
exports.isFieldRendered = function (validEntity) {
    return cond_1.ifNotNilThanValue(validEntity, function () { return validEntity.fieldRendered !== false; }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IPreventFocusWrapper} preventFocusEntity
 * @returns {boolean}
 */
exports.isFocusPrevented = function (preventFocusEntity) {
    return cond_1.ifNotNilThanValue(preventFocusEntity, function () { return preventFocusEntity.preventFocus === true; }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IProgressWrapper} progressEntity
 * @returns {boolean}
 */
exports.inProgress = function (progressEntity) {
    return cond_1.ifNotNilThanValue(progressEntity, function () { return progressEntity.progress === true; }, false);
};
/**
 * @stable [15.01.2020]
 * @param {TEntity} checkScrim
 * @returns {boolean}
 */
exports.isCheckScrimNeeded = function (checkScrim) {
    return cond_1.ifNotNilThanValue(checkScrim, function () { return checkScrim.checkScrim === true; }, false);
};
/**
 * @stable [28.11.2019]
 * @param {IReadyWrapper} entity
 * @returns {boolean}
 */
exports.isReady = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.ready === true; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IFullWrapper} entity
 * @returns {boolean}
 */
exports.isFull = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.full !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IScrollableWrapper} entity
 * @returns {boolean}
 */
exports.isScrollable = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.scrollable !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IDefaultWrapper} entity
 * @returns {boolean}
 */
exports.isDefault = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.default !== false; }, false);
};
/**
 * @stable [28.11.2019]
 * @param {IErrorWrapper} entity
 * @returns {boolean}
 */
exports.doesErrorExist = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () {
        return type_1.isBoolean(entity.error)
            ? entity.error === true
            : !R.isNil(entity.error);
    }, false);
};
/**
 * @stable [24.10.2019]
 * @param {IUseKeyboardWrapper} useKeyboardEntity
 * @returns {boolean}
 */
exports.isKeyboardUsed = function (useKeyboardEntity) {
    return cond_1.ifNotNilThanValue(useKeyboardEntity, function () { return useKeyboardEntity.useKeyboard === true; }, false);
};
/**
 * @stable [25.10.2019]
 * @param {IVisibleWrapper} visibleEntity
 * @returns {boolean}
 */
exports.isVisible = function (visibleEntity) {
    return cond_1.ifNotNilThanValue(visibleEntity, function () { return visibleEntity.visible !== false; }, false);
};
/**
 * @stable [30.10.2019]
 * @param {IFocusedWrapper} wrapper
 * @returns {boolean}
 */
exports.isFocused = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.focused === true; }, false);
};
/**
 * @stable [20.01.2020]
 * @param {IRangeEnabledWrapper} wrapper
 * @returns {boolean}
 */
exports.isRangeEnabled = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.rangeEnabled === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IHighlightOddWrapper} highlightOddEntity
 * @param {number} index
 * @returns {boolean}
 */
exports.isHighlightOdd = function (highlightOddEntity, index) {
    return cond_1.ifNotNilThanValue(highlightOddEntity, function () { return highlightOddEntity.highlightOdd !== false && (type_1.isNumber(index) ? calc_1.isOddNumber(index) : false); }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IIndexedWrapper} indexedEntity
 * @returns {boolean}
 */
exports.isIndexed = function (indexedEntity) {
    return cond_1.ifNotNilThanValue(indexedEntity, function () { return indexedEntity.indexed === true; }, false);
};
/**
 * @stable [03.01.2019]
 * @param {IHeaderRenderedWrapper} headerRendered
 * @returns {boolean}
 */
exports.isHeaderRendered = function (headerRendered) {
    return cond_1.ifNotNilThanValue(headerRendered, function () { return headerRendered.headerRendered !== false; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IRenderedWrapper} value
 * @returns {boolean}
 */
exports.isRendered = function (value) {
    return cond_1.ifNotNilThanValue(value, function () { return value.rendered !== false; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {IEditedWrapper} editedEntity
 * @returns {boolean}
 */
exports.isEdited = function (editedEntity) {
    return cond_1.ifNotNilThanValue(editedEntity, function () { return editedEntity.edited === true; }, false);
};
/**
 * @stable [26.10.2019]
 * @param {ISortableWrapper} sortableEntity
 * @returns {boolean}
 */
exports.isSortable = function (sortableEntity) {
    return cond_1.ifNotNilThanValue(sortableEntity, function () { return sortableEntity.sortable === true; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IDisabledWrapper} disabledEntity
 * @returns {boolean}
 */
exports.isDisabled = function (disabledEntity) {
    return cond_1.ifNotNilThanValue(disabledEntity, function () { return disabledEntity.disabled === true; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IDisabledWrapper} selectedWrapper
 * @returns {boolean}
 */
exports.isSelected = function (selectedWrapper) {
    return cond_1.ifNotNilThanValue(selectedWrapper, function () { return selectedWrapper.selected === true; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {ISelectableWrapper} selectableWrapper
 * @returns {boolean}
 */
exports.isSelectable = function (selectableWrapper) {
    return cond_1.ifNotNilThanValue(selectableWrapper, function () { return selectableWrapper.selectable !== false; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IHoveredWrapper} hoveredWrapper
 * @returns {boolean}
 */
exports.isHovered = function (hoveredWrapper) {
    return cond_1.ifNotNilThanValue(hoveredWrapper, function () { return hoveredWrapper.hovered !== false; }, false);
};
/**
 * @stable [27.10.2019]
 * @param {IExpandActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isExpandActionRendered = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.expandActionRendered !== false; }, false);
};
/**
 * @stable [21.01.2020]
 * @param {ICalendarActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isCalendarActionRendered = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.calendarActionRendered !== false; }, false);
};
/**
 * @stable [01.12.2019]
 * @param {IClearActionRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isClearActionRendered = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.clearActionRendered !== false; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IReadOnlyWrapper} wrapper
 * @returns {boolean}
 */
exports.isReadOnly = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.readOnly === true; }, false);
};
/**
 * @stable [22.01.2020]
 * @param {IInlineWrapper} wrapper
 * @returns {boolean}
 */
exports.isInline = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.inline === true; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IChangeableWrapper} changeableWrapper
 * @returns {boolean}
 */
exports.isChangeable = function (changeableWrapper) {
    return cond_1.ifNotNilThanValue(changeableWrapper, function () { return changeableWrapper.changeable !== false; }, false);
};
/**
 * @stable [28.10.2019]
 * @param {IKeyboardOpenWrapper} wrapper
 * @returns {boolean}
 */
exports.isKeyboardOpen = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.keyboardOpen === true; }, false);
};
/**
 * @stable [29.10.2019]
 * @param {IRequiredWrapper} wrapper
 * @returns {boolean}
 */
exports.isRequired = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.required === true; }, false);
};
/**
 * @stable [30.10.2019]
 * @param {ISyntheticCursorWrapper} wrapper
 * @returns {boolean}
 */
exports.isSyntheticCursorUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.syntheticCursor !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IDecoratedWrapper} wrapper
 * @returns {boolean}
 */
exports.isDecorated = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.decorated !== false; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IRippledWrapper} wrapper
 * @returns {boolean}
 */
exports.isRippled = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.rippled !== false; }, false);
};
/**
 * @stable [13.11.2019]
 * @param {IMultiWrapper} wrapper
 * @returns {boolean}
 */
exports.isMulti = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.multi === true; }, false);
};
/**
 * @stable [23.11.2019]
 * @param {IRemoteFilterWrapper} wrapper
 * @returns {boolean}
 */
exports.isRemoteFilterApplied = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.remoteFilter === true; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IMenuRenderedWrapper} wrapper
 * @returns {boolean}
 */
exports.isMenuRendered = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.menuRendered === true; }, false);
};
/**
 * @stable [24.01.2020]
 * @param {IAnchoredWrapper} wrapper
 * @returns {boolean}
 */
exports.isAnchored = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.anchored === true; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IWaitingForDataWrapper} wrapper
 * @returns {boolean}
 */
exports.isWaitingForData = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.waitingForData === true; }, false);
};
/**
 * @stable [16.01.2020]
 * @param {ITouchedWrapper} wrapper
 * @returns {boolean}
 */
exports.isTouched = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.touched === true; }, false);
};
/**
 * @stable [23.11.2019]
 * @param {IUseFilterWrapper} wrapper
 * @returns {boolean}
 */
exports.isFilterUsed = function (wrapper) {
    return cond_1.ifNotNilThanValue(wrapper, function () { return wrapper.useFilter === true; }, false);
};
/**
 * @stable [22.11.2019]
 * @param {ILoadingWrapper} entity
 * @returns {boolean}
 */
exports.isBeingLoaded = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.loading === true; }, false);
};
/**
 * @stable [26.11.2019]
 * @param {IPlaceActionRenderedWrapper} entity
 * @returns {boolean}
 */
exports.isPlaceActionRendered = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.placeActionRendered !== false; }, false);
};
/**
 * @stable [11.01.2020]
 * @param {IUseZipCodeWrapper} entity
 * @returns {boolean}
 */
exports.isUseZipCode = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.useZipCode === true; }, false);
};
/**
 * @stable [14.01.2020]
 * @param {IPlainValueWrapper} entity
 * @returns {boolean}
 */
exports.isPlainValueApplied = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.plainValue === true; }, false);
};
/**
 * @stable [19.12.2019]
 * @param {IRefreshOnUpdateWrapper} entity
 * @returns {boolean}
 */
exports.isRefreshOnUpdate = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.refreshOnUpdate === true; }, false);
};
/**
 * @stable [21.12.2019]
 * @param {IDisplayValueOnlyWrapper} entity
 * @returns {boolean}
 */
exports.isDisplayValueOnly = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.displayValueOnly === true; }, false);
};
/**
 * @stable [26.12.2019]
 * @param {IAlwaysDirtyWrapper} entity
 * @returns {boolean}
 */
exports.isAlwaysDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.alwaysDirty === true; }, false);
};
/**
 * @stable [26.12.2019]
 * @param {IDirtyWrapper} entity
 * @returns {boolean}
 */
exports.isDirty = function (entity) {
    return cond_1.ifNotNilThanValue(entity, function () { return entity.dirty === true; }, false);
};
//# sourceMappingURL=wrapper.js.map